import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import NotesNote, NotesNoteComment
from vkbottle_types.responses.base_response import BaseResponse


class NotesAddResponse(BaseResponse):
    response: int = Field()


class NotesCreateCommentResponse(BaseResponse):
    response: int = Field()


class NotesGetByIdResponse(BaseResponse):
    response: "NotesNote" = Field()


class NotesGetCommentsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["NotesNoteComment"] = Field()


class NotesGetCommentsResponse(BaseResponse):
    response: "NotesGetCommentsResponseModel" = Field()


class NotesGetResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["NotesNote"] = Field()


class NotesGetResponse(BaseResponse):
    response: "NotesGetResponseModel" = Field()



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    BaseImage,
    BaseUploadServer,
    GroupsGroupFull,
    PhotosPhoto,
    PhotosPhotoAlbumFull,
    PhotosPhotoTag,
    PhotosPhotoUpload,
    PhotosPhotoXtrTagInfo,
    UsersUserFull,
    WallWallComment,
)
from vkbottle_types.responses.base_response import BaseResponse


class PhotosCopyResponse(BaseResponse):
    response: int = Field()


class PhotosCreateAlbumResponse(BaseResponse):
    response: "PhotosPhotoAlbumFull" = Field()


class PhotosCreateCommentResponse(BaseResponse):
    response: int = Field()


class PhotosGetAlbumsCountResponse(BaseResponse):
    response: int = Field()


class PhotosGetAlbumsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["PhotosPhotoAlbumFull"] = Field()


class PhotosGetAlbumsResponse(BaseResponse):
    response: "PhotosGetAlbumsResponseModel" = Field()


class PhotosGetAllCommentsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["WallWallComment"] = Field()


class PhotosGetAllCommentsResponse(BaseResponse):
    response: "PhotosGetAllCommentsResponseModel" = Field()


class PhotosGetAllResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["PhotosPhoto"] = Field()
    more: typing.Optional[bool] = Field(
        default=None,
    )


class PhotosGetAllResponse(BaseResponse):
    response: "PhotosGetAllResponseModel" = Field()


class PhotosGetByIdResponse(BaseResponse):
    response: typing.List["PhotosPhoto"] = Field()


class PhotosGetCommentsExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["WallWallComment"] = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()
    real_offset: typing.Optional[int] = Field(
        default=None,
    )


class PhotosGetCommentsExtendedResponse(BaseResponse):
    response: "PhotosGetCommentsExtendedResponseModel" = Field()


class PhotosGetCommentsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["WallWallComment"] = Field()
    real_offset: typing.Optional[int] = Field(
        default=None,
    )


class PhotosGetCommentsResponse(BaseResponse):
    response: "PhotosGetCommentsResponseModel" = Field()


class PhotosGetMarketUploadServerResponse(BaseResponse):
    response: "BaseUploadServer" = Field()


class PhotosGetMessagesUploadServerResponse(BaseResponse):
    response: "PhotosPhotoUpload" = Field()


class PhotosGetNewTagsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["PhotosPhotoXtrTagInfo"] = Field()


class PhotosGetNewTagsResponse(BaseResponse):
    response: "PhotosGetNewTagsResponseModel" = Field()


class PhotosGetTagsResponse(BaseResponse):
    response: typing.List["PhotosPhotoTag"] = Field()


class PhotosGetUploadServerResponse(BaseResponse):
    response: "PhotosPhotoUpload" = Field()


class PhotosGetUserPhotosResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["PhotosPhoto"] = Field()
    next_from: typing.Optional[str] = Field(
        default=None,
    )


class PhotosGetUserPhotosResponse(BaseResponse):
    response: "PhotosGetUserPhotosResponseModel" = Field()


class PhotosGetWallUploadServerResponse(BaseResponse):
    response: "PhotosPhotoUpload" = Field()


class PhotosGetResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["PhotosPhoto"] = Field()
    next_from: typing.Optional[str] = Field(
        default=None,
    )


class PhotosGetResponse(BaseResponse):
    response: "PhotosGetResponseModel" = Field()


class PhotosMarketAlbumUploadResponseModel(BaseModel):
    gid: typing.Optional[int] = Field(
        default=None,
    )
    hash: typing.Optional[str] = Field(
        default=None,
    )
    photo: typing.Optional[str] = Field(
        default=None,
    )
    server: typing.Optional[int] = Field(
        default=None,
    )


class PhotosMarketAlbumUploadResponse(BaseResponse):
    response: "PhotosMarketAlbumUploadResponseModel" = Field()


class PhotosMarketUploadResponseModel(BaseModel):
    crop_data: typing.Optional[str] = Field(
        default=None,
    )
    crop_hash: typing.Optional[str] = Field(
        default=None,
    )
    group_id: typing.Optional[int] = Field(
        default=None,
    )
    hash: typing.Optional[str] = Field(
        default=None,
    )
    photo: typing.Optional[str] = Field(
        default=None,
    )
    server: typing.Optional[int] = Field(
        default=None,
    )


class PhotosMarketUploadResponse(BaseResponse):
    response: "PhotosMarketUploadResponseModel" = Field()


class PhotosMessageUploadResponseModel(BaseModel):
    hash: typing.Optional[str] = Field(
        default=None,
    )
    photo: typing.Optional[str] = Field(
        default=None,
    )
    server: typing.Optional[int] = Field(
        default=None,
    )


class PhotosMessageUploadResponse(BaseResponse):
    response: "PhotosMessageUploadResponseModel" = Field()


class PhotosOwnerCoverUploadResponseModel(BaseModel):
    hash: typing.Optional[str] = Field(
        default=None,
    )
    photo: typing.Optional[str] = Field(
        default=None,
    )


class PhotosOwnerCoverUploadResponse(BaseResponse):
    response: "PhotosOwnerCoverUploadResponseModel" = Field()


class PhotosOwnerUploadResponseModel(BaseModel):
    hash: typing.Optional[str] = Field(
        default=None,
    )
    photo: typing.Optional[str] = Field(
        default=None,
    )
    server: typing.Optional[int] = Field(
        default=None,
    )


class PhotosOwnerUploadResponse(BaseResponse):
    response: "PhotosOwnerUploadResponseModel" = Field()


class PhotosPhotoUploadResponseModel(BaseModel):
    aid: typing.Optional[int] = Field(
        default=None,
    )
    hash: typing.Optional[str] = Field(
        default=None,
    )
    photo: typing.Optional[str] = Field(
        default=None,
    )
    photos_list: typing.Optional[str] = Field(
        default=None,
    )
    server: typing.Optional[int] = Field(
        default=None,
    )


class PhotosPhotoUploadResponse(BaseResponse):
    response: "PhotosPhotoUploadResponseModel" = Field()


class PhotosPutTagResponse(BaseResponse):
    response: int = Field()


class PhotosSaveMarketAlbumPhotoResponse(BaseResponse):
    response: typing.List["PhotosPhoto"] = Field()


class PhotosSaveMarketPhotoResponse(BaseResponse):
    response: typing.List["PhotosPhoto"] = Field()


class PhotosSaveMessagesPhotoResponse(BaseResponse):
    response: typing.List["PhotosPhoto"] = Field()


class PhotosSaveOwnerCoverPhotoResponseModel(BaseModel):
    images: typing.Optional[typing.List["BaseImage"]] = Field(
        default=None,
    )


class PhotosSaveOwnerCoverPhotoResponse(BaseResponse):
    response: "PhotosSaveOwnerCoverPhotoResponseModel" = Field()


class PhotosSaveOwnerPhotoResponseModel(BaseModel):
    photo_hash: str = Field()
    photo_src: str = Field()
    photo_src_big: typing.Optional[str] = Field(
        default=None,
    )
    photo_src_small: typing.Optional[str] = Field(
        default=None,
    )
    saved: typing.Optional[int] = Field(
        default=None,
    )
    post_id: typing.Optional[int] = Field(
        default=None,
    )


class PhotosSaveOwnerPhotoResponse(BaseResponse):
    response: "PhotosSaveOwnerPhotoResponseModel" = Field()


class PhotosSaveWallPhotoResponse(BaseResponse):
    response: typing.List["PhotosPhoto"] = Field()


class PhotosSaveResponse(BaseResponse):
    response: typing.List["PhotosPhoto"] = Field()


class PhotosSearchResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["PhotosPhoto"] = Field()


class PhotosSearchResponse(BaseResponse):
    response: "PhotosSearchResponseModel" = Field()


class PhotosWallUploadResponseModel(BaseModel):
    hash: typing.Optional[str] = Field(
        default=None,
    )
    photo: typing.Optional[str] = Field(
        default=None,
    )
    server: typing.Optional[int] = Field(
        default=None,
    )


class PhotosWallUploadResponse(BaseResponse):
    response: "PhotosWallUploadResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.gifts import *  # noqa: F401,F403  # type: ignore


class GiftsCategory(BaseCategory):
    async def get(
        self,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> GiftsGetResponseModel:
        """Method `gifts.get()`

        :param count: Number of gifts to return.
        :param offset: Offset needed to return a specific subset of results.
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("gifts.get", params)
        model = GiftsGetResponse
        return model(**response).response


__all__ = ("GiftsCategory",)



from .bot_events import (
    AppPayload,
    AudioNew,
    BoardPostDelete,
    BoardPostEdit,
    BoardPostNew,
    BoardPostRestore,
    DonutMoneyWithdraw,
    DonutMoneyWithdrawError,
    DonutSubscriptionCancelled,
    DonutSubscriptionCreate,
    DonutSubscriptionExpired,
    DonutSubscriptionPriceChanged,
    DonutSubscriptionProlonged,
    GroupChangePhoto,
    GroupChangeSettings,
    GroupJoin,
    GroupLeave,
    GroupOfficersEdit,
    LeadFormsNew,
    LikeAdd,
    LikeRemove,
    MarketCommentDelete,
    MarketCommentEdit,
    MarketCommentNew,
    MarketCommentRestore,
    MarketOrderEdit,
    MarketOrderNew,
    MessageAllow,
    MessageDeny,
    MessageEdit,
    MessageEvent,
    MessageNew,
    MessageReactionEvent,
    MessageRead,
    MessageReply,
    MessageTypingState,
    PhotoCommentDelete,
    PhotoCommentEdit,
    PhotoCommentNew,
    PhotoCommentRestore,
    PhotoNew,
    PollVoteNew,
    UserBlock,
    UserUnblock,
    VideoCommentDelete,
    VideoCommentEdit,
    VideoCommentNew,
    VideoCommentRestore,
    VideoNew,
    VkpayTransaction,
    WallPostNew,
    WallReplyDelete,
    WallReplyEdit,
    WallReplyNew,
    WallReplyRestore,
    WallRepost,
)


class GroupTypes:
    MessageNew = MessageNew
    MessageReply = MessageReply
    MessageEdit = MessageEdit
    MessageRead = MessageRead
    MessageAllow = MessageAllow
    MessageDeny = MessageDeny
    MessageReactionEvent = MessageReactionEvent
    MessageTypingState = MessageTypingState
    MessageEvent = MessageEvent
    PhotoNew = PhotoNew
    PhotoCommentNew = PhotoCommentNew
    PhotoCommentEdit = PhotoCommentEdit
    PhotoCommentRestore = PhotoCommentRestore
    PhotoCommentDelete = PhotoCommentDelete
    AudioNew = AudioNew
    VideoNew = VideoNew
    VideoCommentNew = VideoCommentNew
    VideoCommentEdit = VideoCommentEdit
    VideoCommentRestore = VideoCommentRestore
    VideoCommentDelete = VideoCommentDelete
    WallPostNew = WallPostNew
    WallRepost = WallRepost
    WallReplyNew = WallReplyNew
    WallReplyEdit = WallReplyEdit
    WallReplyRestore = WallReplyRestore
    WallReplyDelete = WallReplyDelete
    LeadFormsNew = LeadFormsNew
    LikeAdd = LikeAdd
    LikeRemove = LikeRemove
    BoardPostNew = BoardPostNew
    BoardPostEdit = BoardPostEdit
    BoardPostRestore = BoardPostRestore
    BoardPostDelete = BoardPostDelete
    MarketCommentNew = MarketCommentNew
    MarketCommentEdit = MarketCommentEdit
    MarketCommentRestore = MarketCommentRestore
    MarketCommentDelete = MarketCommentDelete
    MarketOrderNew = MarketOrderNew
    MarketOrderEdit = MarketOrderEdit
    GroupLeave = GroupLeave
    GroupJoin = GroupJoin
    UserBlock = UserBlock
    UserUnblock = UserUnblock
    PollVoteNew = PollVoteNew
    GroupOfficersEdit = GroupOfficersEdit
    GroupChangeSettings = GroupChangeSettings
    GroupChangePhoto = GroupChangePhoto
    VkpayTransaction = VkpayTransaction
    AppPayload = AppPayload
    DonutSubscriptionCreate = DonutSubscriptionCreate
    DonutSubscriptionProlonged = DonutSubscriptionProlonged
    DonutSubscriptionExpired = DonutSubscriptionExpired
    DonutSubscriptionCancelled = DonutSubscriptionCancelled
    DonutSubscriptionPriceChanged = DonutSubscriptionPriceChanged
    DonutMoneyWithdraw = DonutMoneyWithdraw
    DonutMoneyWithdrawError = DonutMoneyWithdrawError


__all__ = ("GroupTypes",)



import enum
from typing import Any, Dict, List, Optional, Union

import msgspec

Attachments = Union[Dict[str, Any], List[Any]]


class BaseEventObject(msgspec.Struct, omit_defaults=True, array_like=True):
    pass


class MessageObject(BaseEventObject):
    message_id: Optional[int] = None
    mask: Optional[int] = None
    peer_id: Optional[int] = None
    timestamp: Optional[int] = None
    chat_title: Optional[str] = ""
    new_text: Optional[str] = ""
    attachments: Optional[Attachments] = None


class ReplaceMessageFlagsObject(MessageObject):
    flags: Optional[int] = None


class InstallMessageFlagsObject(MessageObject):
    flags: Optional[int] = None


class ResetMessageFlagsObject(MessageObject):
    flags: Optional[int] = None


class MessageNewObject(MessageObject):
    random_id: Optional[int] = None


class MessageEditObject(MessageObject):
    pass


class InReadObject(BaseEventObject):
    peer_id: Optional[int] = None
    local_id: Optional[int] = None


class OutReadObject(InReadObject):
    pass


class FriendOnlineObject(BaseEventObject):
    user_id: Optional[int] = None
    extra: Optional[int] = 0
    timestamp: Optional[int] = None


class FriendOfflineObject(BaseEventObject):
    user_id: Optional[int] = None
    flags: Optional[int] = 0
    timestamp: Optional[int] = None


class ResetDialogFlagsObject(BaseEventObject):
    peer_id: Optional[int] = None
    mask: Optional[int] = None


class ReplaceDialogFlagsObject(BaseEventObject):
    peer_id: Optional[int] = None
    flags: Optional[int] = None


class InstallDialogFlagsObject(ResetDialogFlagsObject):
    pass


class MessagesDeleteObject(InReadObject):
    pass


class MessagesRestoreObject(InReadObject):
    pass


class ChangeConversationParamsObject(BaseEventObject):
    chat_id: Optional[int] = None
    self: Optional[int] = None


class DialogTypingStateObject(BaseEventObject):
    user_id: Optional[int] = None
    flags: Optional[int] = None


class ConversationTypingStateObject(BaseEventObject):
    user_id: Optional[int] = None
    chat_id: Optional[int] = None


class UsersTypingStateObject(BaseEventObject):
    user_ids: Optional[List[int]] = None
    peer_id: Optional[int] = None
    total_count: Optional[int] = None
    ts: Optional[int] = None


class CallObject(BaseEventObject):
    user_id: Optional[int] = None
    call_id: Optional[int] = None


class CounterObject(BaseEventObject):
    count: Optional[int] = None


class NotificationsSettingsChangedObject(BaseEventObject):
    peer_id: Optional[int] = None
    sound: Optional[int] = None
    disabled_until: Optional[int] = None


class ChatInfoEditObject(BaseEventObject):
    type_id: Optional[int] = None
    peer_id: Optional[int] = None
    info: Optional[Union[str, int]] = None


class ChatVoiceMessageStatesObject(BaseEventObject):
    user_ids: Optional[List[int]] = None
    peer_id: Optional[int] = None
    total_count: Optional[int] = None
    ts: Optional[int] = None


class ChatEditObject(BaseEventObject):
    chat_id: Optional[int] = None
    self: Optional[int] = None


class ActionType(enum.IntEnum):
    ACCEPT = 2
    REMOVE_OR_CANCEL = 3


class FriendActionObject(BaseEventObject):
    action_type: Optional[ActionType] = None
    user_id: Optional[int] = None


class CreateFolderObject(BaseEventObject):
    folder_id: Optional[int] = None
    folder_name: Optional[str] = None
    random_id: Optional[int] = None


class DeleteFolderObject(BaseEventObject):
    folder_id: Optional[int] = None


class RenameFolderObject(BaseEventObject):
    folder_id: Optional[int] = None
    new_folder_name: Optional[str] = None


class AddConversationsToFolderObject(BaseEventObject):
    folder_id: Optional[int] = None
    peer_ids: Optional[List[int]] = None


class RemoveConversationsFromFolderObject(BaseEventObject):
    folder_id: Optional[int] = None
    peer_ids: Optional[List[int]] = None


class ChangeFolderOrderObject(BaseEventObject):
    folder_ids: Optional[List[int]] = None


class CounterUnreadDialogsInFoldersObject(BaseEventObject):
    folder_id: Optional[int] = None
    unread_count: Optional[int] = None
    unread_unmuted_count: Optional[int] = None


__all__ = (
    "AddConversationsToFolderObject",
    "CallObject",
    "ChatEditObject",
    "ChatInfoEditObject",
    "ChatVoiceMessageStatesObject",
    "ChangeConversationParamsObject",
    "ChangeFolderOrderObject",
    "ConversationTypingStateObject",
    "CounterObject",
    "CounterUnreadDialogsInFoldersObject",
    "CreateFolderObject",
    "DeleteFolderObject",
    "DialogTypingStateObject",
    "FriendActionObject",
    "FriendOfflineObject",
    "FriendOnlineObject",
    "InReadObject",
    "InstallDialogFlagsObject",
    "InstallMessageFlagsObject",
    "MessagesDeleteObject",
    "MessagesRestoreObject",
    "NotificationsSettingsChangedObject",
    "OutReadObject",
    "RemoveConversationsFromFolderObject",
    "ReplaceDialogFlagsObject",
    "ReplaceMessageFlagsObject",
    "ResetDialogFlagsObject",
    "ResetMessageFlagsObject",
    "RenameFolderObject",
    "UsersTypingStateObject",
)



import typing

from typing_extensions import Literal

from vkbottle_types.codegen.methods.video import VideoCategory  # type: ignore
from vkbottle_types.codegen.responses.base import BaseOkResponse, BaseOkResponseModel
from vkbottle_types.codegen.responses.video import VideoChangeVideoAlbumsResponse


class VideoCategory(VideoCategory):
    @typing.overload
    async def add_to_album(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = ...,
        album_ids: typing.Optional[Literal[None]] = None,
        **kwargs,
    ) -> BaseOkResponseModel: ...

    @typing.overload
    async def add_to_album(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        album_id: typing.Optional[Literal[None]] = None,
        album_ids: typing.Optional[typing.List[int]] = ...,
        **kwargs,
    ) -> typing.List[int]: ...

    async def add_to_album(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = None,
        album_ids: typing.Optional[typing.List[int]] = None,
        **kwargs,
    ) -> typing.Union[BaseOkResponseModel, typing.List[int]]:
        """video.addToAlbum method

        :param owner_id:
        :param video_id:
        :param target_id:
        :param album_id:
        :param album_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.addToAlbum", params)
        model = self.get_model(
            ((("album_ids",), VideoChangeVideoAlbumsResponse),),
            default=BaseOkResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def remove_from_album(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = ...,
        album_ids: typing.Optional[Literal[None]] = None,
        **kwargs,
    ) -> BaseOkResponseModel: ...

    @typing.overload
    async def remove_from_album(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        album_id: typing.Optional[Literal[None]] = None,
        album_ids: typing.Optional[typing.List[int]] = ...,
        **kwargs,
    ) -> typing.List[int]: ...

    async def remove_from_album(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = None,
        album_ids: typing.Optional[typing.List[int]] = None,
        **kwargs,
    ) -> typing.Union[BaseOkResponseModel, typing.List[int]]:
        """video.removeFromAlbum method

        :param owner_id:
        :param video_id:
        :param target_id:
        :param album_id:
        :param album_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.removeFromAlbum", params)
        model = self.get_model(
            ((("album_ids",), VideoChangeVideoAlbumsResponse),),
            default=BaseOkResponse,
            params=params,
        )
        return model(**response).response


__all__ = ("VideoCategory",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import AppsAppFields, AppsTestingGroup, UsersFields
from vkbottle_types.responses.apps import *  # noqa: F401,F403  # type: ignore
from vkbottle_types.responses.base import (
    BaseBoolResponse,
    BaseOkResponse,
    BaseOkResponseModel,
)


class AppsCategory(BaseCategory):
    async def add_snippet(
        self,
        button: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        group_id: typing.Optional[typing.List[int]] = None,
        hash: typing.Optional[typing.List[str]] = None,
        image_url: typing.Optional[str] = None,
        small_image_url: typing.Optional[str] = None,
        snippet_id: typing.Optional[int] = None,
        title: typing.Optional[str] = None,
        vk_ref: typing.Optional[typing.List[typing.Literal["snippet_im", "snippet_post"]]] = None,
        **kwargs: typing.Any,
    ) -> AppsAddSnippetResponseModel:
        """Method `apps.addSnippet()`

        :param button:
        :param description:
        :param group_id:
        :param hash:
        :param image_url:
        :param small_image_url:
        :param snippet_id:
        :param title:
        :param vk_ref:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.addSnippet", params)
        model = AppsAddSnippetResponse
        return model(**response).response

    async def add_users_to_testing_group(
        self,
        group_id: int,
        user_ids: typing.List[int],
        **kwargs: typing.Any,
    ) -> bool:
        """Method `apps.addUsersToTestingGroup()`

        :param group_id:
        :param user_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.addUsersToTestingGroup", params)
        model = BaseBoolResponse
        return model(**response).response

    async def delete_app_requests(
        self,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `apps.deleteAppRequests()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("apps.deleteAppRequests", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_snippet(
        self,
        id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `apps.deleteSnippet()`

        :param id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.deleteSnippet", params)
        model = BaseOkResponse
        return model(**response).response

    async def get(
        self,
        app_fields: typing.Optional[typing.List[AppsAppFields]] = None,
        app_id: typing.Optional[int] = None,
        app_ids: typing.Optional[typing.List[int]] = None,
        extended: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        name_case: typing.Optional[str] = None,
        platform: typing.Optional[str] = None,
        return_friends: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> AppsGetResponseModel:
        """Method `apps.get()`

        :param app_fields: List of app fields to return. Fields 'id', 'type' and 'title' will always be in response. Leave this field empty to get all fields
        :param app_id: Application ID
        :param app_ids: List of application ID
        :param extended:
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'contacts', 'education', 'online', 'counters', 'relation', 'last_seen', 'activity', 'can_write_private_message', 'can_see_all_posts', 'can_post', 'universities', (only if return_friends - 1)
        :param name_case: Case for declension of user name and surname: 'nom' - nominative (default),, 'gen' - genitive,, 'dat' - dative,, 'acc' - accusative,, 'ins' - instrumental,, 'abl' - prepositional. (only if 'return_friends' = '1')
        :param platform: platform. Possible values: *'ios' - iOS,, *'android' - Android,, *'winphone' - Windows Phone,, *'web' - приложения на vk.com. By default: 'web'.
        :param return_friends:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.get", params)
        model = AppsGetResponse
        return model(**response).response

    async def get_catalog(
        self,
        count: typing.Optional[int] = None,
        extended: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        filter: typing.Optional[str] = None,
        genre_id: typing.Optional[int] = None,
        name_case: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        platform: typing.Optional[str] = None,
        q: typing.Optional[str] = None,
        return_friends: typing.Optional[bool] = None,
        sort: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> "AppsCatalogList":
        """Method `apps.getCatalog()`

        :param count: Number of apps to return.
        :param extended: '1' - to return additional fields 'screenshots', 'MAU', 'catalog_position', and 'international'. If set, 'count' must be less than or equal to '100'. '0' - not to return additional fields (default).
        :param fields:
        :param filter: 'installed' - to return list of installed apps (only for mobile platform).
        :param genre_id:
        :param name_case:
        :param offset: Offset required to return a specific subset of apps.
        :param platform:
        :param q: Search query string.
        :param return_friends:
        :param sort: Sort order: 'popular_today' - popular for one day (default), 'visitors' - by visitors number , 'create_date' - by creation date, 'growth_rate' - by growth rate, 'popular_week' - popular for one week
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.getCatalog", params)
        model = AppsGetCatalogResponse
        return model(**response).response

    @typing.overload
    async def get_friends_list(
        self,
        extended: typing.Literal[True],
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        offset: typing.Optional[int] = None,
        query: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> AppsGetFriendsListExtendedResponseModel: ...

    @typing.overload
    async def get_friends_list(
        self,
        extended: typing.Optional[typing.Literal[False]] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        offset: typing.Optional[int] = None,
        query: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> AppsGetFriendsListResponseModel: ...

    async def get_friends_list(
        self,
        extended: typing.Optional[bool] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        offset: typing.Optional[int] = None,
        query: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[AppsGetFriendsListResponseModel, AppsGetFriendsListExtendedResponseModel]:
        """Method `apps.getFriendsList()`

        :param extended:
        :param count: List size.
        :param fields: Additional profile fields, see [vk.com/dev/fields|description].
        :param offset:
        :param query: Search query string (e.g., 'Vasya Babich').
        :param type: List type. Possible values: * 'invite' - available for invites (don't play the game),, * 'request' - available for request (play the game). By default: 'invite'.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.getFriendsList", params)
        model = self.get_model(
            ((("extended",), AppsGetFriendsListExtendedResponse),),
            default=AppsGetFriendsListResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def get_leaderboard(
        self,
        type: str,
        extended: typing.Literal[True],
        _global: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> AppsGetLeaderboardExtendedResponseModel: ...

    @typing.overload
    async def get_leaderboard(
        self,
        type: str,
        extended: typing.Optional[typing.Literal[False]] = None,
        _global: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> AppsGetLeaderboardResponseModel: ...

    async def get_leaderboard(
        self,
        type: str,
        extended: typing.Optional[bool] = None,
        _global: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[AppsGetLeaderboardResponseModel, AppsGetLeaderboardExtendedResponseModel]:
        """Method `apps.getLeaderboard()`

        :param type: Leaderboard type. Possible values: *'level' - by level,, *'points' - by mission points,, *'score' - by score ().
        :param extended: 1 - to return additional info about users
        :param global: Rating type. Possible values: *'1' - global rating among all players,, *'0' - rating among user friends.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.getLeaderboard", params)
        model = self.get_model(
            ((("extended",), AppsGetLeaderboardExtendedResponse),),
            default=AppsGetLeaderboardResponse,
            params=params,
        )
        return model(**response).response

    async def get_mini_app_policies(
        self,
        app_id: int,
        **kwargs: typing.Any,
    ) -> AppsGetMiniAppPoliciesResponseModel:
        """Method `apps.getMiniAppPolicies()`

        :param app_id: Mini App ID
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.getMiniAppPolicies", params)
        model = AppsGetMiniAppPoliciesResponse
        return model(**response).response

    async def get_scopes(
        self,
        type: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> AppsGetScopesResponseModel:
        """Method `apps.getScopes()`

        :param type:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.getScopes", params)
        model = AppsGetScopesResponse
        return model(**response).response

    async def get_score(
        self,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `apps.getScore()`

        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.getScore", params)
        model = AppsGetScoreResponse
        return model(**response).response

    async def get_snippets(
        self,
        **kwargs: typing.Any,
    ) -> AppsGetSnippetsResponseModel:
        """Method `apps.getSnippets()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("apps.getSnippets", params)
        model = AppsGetSnippetsResponse
        return model(**response).response

    async def get_testing_groups(
        self,
        group_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.List[AppsTestingGroup]:
        """Method `apps.getTestingGroups()`

        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.getTestingGroups", params)
        model = AppsGetTestingGroupsResponse
        return model(**response).response

    async def is_notifications_allowed(
        self,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> AppsIsNotificationsAllowedResponseModel:
        """Method `apps.isNotificationsAllowed()`

        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.isNotificationsAllowed", params)
        model = AppsIsNotificationsAllowedResponse
        return model(**response).response

    async def promo_has_active_gift(
        self,
        promo_id: int,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `apps.promoHasActiveGift()`

        :param promo_id: Id of game promo action
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.promoHasActiveGift", params)
        model = BaseBoolResponse
        return model(**response).response

    async def promo_use_gift(
        self,
        promo_id: int,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `apps.promoUseGift()`

        :param promo_id: Id of game promo action
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.promoUseGift", params)
        model = BaseBoolResponse
        return model(**response).response

    async def remove_testing_group(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `apps.removeTestingGroup()`

        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.removeTestingGroup", params)
        model = BaseBoolResponse
        return model(**response).response

    async def remove_users_from_testing_groups(
        self,
        user_ids: typing.List[int],
        **kwargs: typing.Any,
    ) -> bool:
        """Method `apps.removeUsersFromTestingGroups()`

        :param user_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.removeUsersFromTestingGroups", params)
        model = BaseBoolResponse
        return model(**response).response

    async def send_request(
        self,
        user_id: int,
        key: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        separate: typing.Optional[bool] = None,
        text: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `apps.sendRequest()`

        :param user_id: id of the user to send a request
        :param key: special string key to be sent with the request
        :param name:
        :param separate:
        :param text: request text
        :param type: request type. Values: 'invite' - if the request is sent to a user who does not have the app installed,, 'request' - if a user has already installed the app
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.sendRequest", params)
        model = AppsSendRequestResponse
        return model(**response).response

    async def update_meta_for_testing_group(
        self,
        name: str,
        platforms: typing.List[typing.Literal["mobile", "web", "mvk"]],
        webview: str,
        group_id: typing.Optional[int] = None,
        user_ids: typing.Optional[typing.List[int]] = None,
        **kwargs: typing.Any,
    ) -> AppsCreatedGroupResponseModel:
        """Method `apps.updateMetaForTestingGroup()`

        :param name:
        :param platforms:
        :param webview:
        :param group_id:
        :param user_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("apps.updateMetaForTestingGroup", params)
        model = AppsCreatedGroupResponse
        return model(**response).response


__all__ = ("AppsCategory",)



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import SearchHint
from vkbottle_types.responses.base_response import BaseResponse


class SearchGetHintsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["SearchHint"] = Field()
    suggested_queries: typing.Optional[typing.List[str]] = Field(
        default=None,
    )


class SearchGetHintsResponse(BaseResponse):
    response: "SearchGetHintsResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.translations import *  # noqa: F401,F403  # type: ignore


class TranslationsCategory(BaseCategory):
    async def translate(
        self,
        texts: typing.List[str],
        translation_language: str,
        **kwargs: typing.Any,
    ) -> TranslationsTranslateResponseModel:
        """Method `translations.translate()`

        :param texts:
        :param translation_language:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("translations.translate", params)
        model = TranslationsTranslateResponse
        return model(**response).response


__all__ = ("TranslationsCategory",)



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    GroupsGroupFull,
    StoriesFeedItem,
    StoriesStatCategory,
    StoriesStory,
    StoriesStoryStats,
    StoriesViewersItem,
    UsersUser,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class StoriesGetBannedExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List[int] = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()


class StoriesGetBannedExtendedResponse(BaseResponse):
    response: "StoriesGetBannedExtendedResponseModel" = Field()


class StoriesGetBannedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List[int] = Field()


class StoriesGetBannedResponse(BaseResponse):
    response: "StoriesGetBannedResponseModel" = Field()


class StoriesGetByIdExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["StoriesStory"] = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()


class StoriesGetByIdExtendedResponse(BaseResponse):
    response: "StoriesGetByIdExtendedResponseModel" = Field()


class StoriesGetPhotoUploadServerResponseModel(BaseModel):
    upload_url: str = Field()
    user_ids: typing.List[int] = Field()


class StoriesGetPhotoUploadServerResponse(BaseResponse):
    response: "StoriesGetPhotoUploadServerResponseModel" = Field()


class StoriesGetStatsV5200ResponseModel(BaseModel):
    preview: typing.Optional[str] = Field(
        default=None,
    )
    achievement: typing.Optional[str] = Field(
        default=None,
    )
    achievement_subtitle: typing.Optional[str] = Field(
        default=None,
    )
    categories: typing.Optional[typing.List["StoriesStatCategory"]] = Field(
        default=None,
    )
    need_privacy_block: typing.Optional[bool] = Field(
        default=None,
    )


class StoriesGetStatsV5200Response(BaseResponse):
    response: "StoriesGetStatsV5200ResponseModel" = Field()


class StoriesGetStatsResponse(BaseResponse):
    response: "StoriesStoryStats" = Field()


class StoriesGetVideoUploadServerResponseModel(BaseModel):
    upload_url: str = Field()
    user_ids: typing.List[int] = Field()


class StoriesGetVideoUploadServerResponse(BaseResponse):
    response: "StoriesGetVideoUploadServerResponseModel" = Field()


class StoriesGetViewersExtendedV5115ResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["StoriesViewersItem"] = Field()
    hidden_reason: typing.Optional[str] = Field(
        default=None,
    )
    next_from: typing.Optional[str] = Field(
        default=None,
    )


class StoriesGetViewersExtendedV5115Response(BaseResponse):
    response: "StoriesGetViewersExtendedV5115ResponseModel" = Field()


class StoriesGetV5113ResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["StoriesFeedItem"] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )
    need_upload_screen: typing.Optional[bool] = Field(
        default=None,
    )
    track_code: typing.Optional[str] = Field(
        default=None,
    )
    next_from: typing.Optional[str] = Field(
        default=None,
    )


class StoriesGetV5113Response(BaseResponse):
    response: "StoriesGetV5113ResponseModel" = Field()


class StoriesSaveResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["StoriesStory"] = Field()
    profiles: typing.Optional[typing.List["UsersUser"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )


class StoriesSaveResponse(BaseResponse):
    response: "StoriesSaveResponseModel" = Field()


class StoriesUploadResponseModel(BaseModel):
    upload_result: typing.Optional[str] = Field(
        default=None,
    )


class StoriesUploadResponse(BaseResponse):
    response: "StoriesUploadResponseModel" = Field()



import typing

from typing_extensions import Literal

from vkbottle_types.codegen.methods.messages import MessagesCategory  # type: ignore
from vkbottle_types.objects import UsersFields
from vkbottle_types.responses.messages import (
    MessagesChat,
    MessagesChatFull,
    MessagesGetChatChatIdsFieldsResponse,
    MessagesGetChatChatIdsResponse,
    MessagesGetChatFieldsResponse,
    MessagesGetChatResponse,
    MessagesSendDeprecatedResponse,
    MessagesSendPeerIdsResponse,
    MessagesSendUserIdsResponse,
    MessagesSendUserIdsResponseItem,
)


class MessagesCategory(MessagesCategory):  # type: ignore
    @typing.overload  # type: ignore
    async def send(  # type: ignore
        self,
        user_id: typing.Optional[int] = None,
        random_id: typing.Optional[int] = None,
        peer_id: typing.Optional[int] = None,
        peer_ids: typing.Optional[typing.List[int]] = None,
        domain: typing.Optional[str] = None,
        chat_id: typing.Optional[int] = None,
        user_ids: typing.Optional[Literal[None]] = ...,
        message: typing.Optional[str] = None,
        lat: typing.Optional[float] = None,
        long: typing.Optional[float] = None,
        attachment: typing.Optional[str] = None,
        reply_to: typing.Optional[int] = None,
        forward_messages: typing.Optional[typing.List[int]] = None,
        forward: typing.Optional[str] = None,
        sticker_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        keyboard: typing.Optional[str] = None,
        template: typing.Optional[str] = None,
        payload: typing.Optional[str] = None,
        content_source: typing.Optional[str] = None,
        dont_parse_links: typing.Optional[bool] = None,
        disable_mentions: typing.Optional[bool] = None,
        intent: typing.Optional[
            Literal[
                "account_update",
                "bot_ad_invite",
                "bot_ad_promo",
                "confirmed_notification",
                "customer_support",
                "default",
                "game_notification",
                "moderated_newsletter",
                "non_promo_newsletter",
                "promo_newsletter",
                "purchase_update",
            ]
        ] = None,
        subscribe_id: typing.Optional[int] = None,
    ) -> int: ...

    @typing.overload
    async def send(
        self,
        user_id: typing.Optional[int] = None,
        random_id: typing.Optional[int] = None,
        peer_id: typing.Optional[int] = None,
        peer_ids: typing.Optional[typing.List[int]] = None,
        domain: typing.Optional[str] = None,
        chat_id: typing.Optional[int] = None,
        user_ids: typing.List[int] = ...,
        message: typing.Optional[str] = None,
        lat: typing.Optional[float] = None,
        long: typing.Optional[float] = None,
        attachment: typing.Optional[str] = None,
        reply_to: typing.Optional[int] = None,
        forward_messages: typing.Optional[typing.List[int]] = None,
        forward: typing.Optional[str] = None,
        sticker_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        keyboard: typing.Optional[str] = None,
        template: typing.Optional[str] = None,
        payload: typing.Optional[str] = None,
        content_source: typing.Optional[str] = None,
        dont_parse_links: typing.Optional[bool] = None,
        disable_mentions: typing.Optional[bool] = None,
        intent: typing.Optional[
            Literal[
                "account_update",
                "bot_ad_invite",
                "bot_ad_promo",
                "confirmed_notification",
                "customer_support",
                "default",
                "game_notification",
                "moderated_newsletter",
                "non_promo_newsletter",
                "promo_newsletter",
                "purchase_update",
            ]
        ] = None,
        subscribe_id: typing.Optional[int] = None,
    ) -> typing.List[MessagesSendUserIdsResponseItem]: ...

    @typing.overload
    async def send(
        self,
        user_id: typing.Optional[int] = None,
        random_id: typing.Optional[int] = None,
        peer_id: typing.Optional[int] = None,
        peer_ids: typing.List[int] = ...,
        domain: typing.Optional[str] = None,
        chat_id: typing.Optional[int] = None,
        user_ids: typing.Optional[typing.List[int]] = None,
        message: typing.Optional[str] = None,
        lat: typing.Optional[float] = None,
        long: typing.Optional[float] = None,
        attachment: typing.Optional[str] = None,
        reply_to: typing.Optional[int] = None,
        forward_messages: typing.Optional[typing.List[int]] = None,
        forward: typing.Optional[str] = None,
        sticker_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        keyboard: typing.Optional[str] = None,
        template: typing.Optional[str] = None,
        payload: typing.Optional[str] = None,
        content_source: typing.Optional[str] = None,
        dont_parse_links: typing.Optional[bool] = None,
        disable_mentions: typing.Optional[bool] = None,
        intent: typing.Optional[
            Literal[
                "account_update",
                "bot_ad_invite",
                "bot_ad_promo",
                "confirmed_notification",
                "customer_support",
                "default",
                "game_notification",
                "moderated_newsletter",
                "non_promo_newsletter",
                "promo_newsletter",
                "purchase_update",
            ]
        ] = None,
        subscribe_id: typing.Optional[int] = None,
    ) -> typing.List[MessagesSendUserIdsResponseItem]: ...

    async def send(
        self,
        user_id=None,
        random_id=None,
        peer_id=None,
        peer_ids=None,
        domain=None,
        chat_id=None,
        user_ids=None,
        message=None,
        lat=None,
        long=None,
        attachment=None,
        reply_to=None,
        forward_messages=None,
        forward=None,
        sticker_id=None,
        group_id=None,
        keyboard=None,
        template=None,
        payload=None,
        content_source=None,
        dont_parse_links=None,
        disable_mentions=None,
        intent=None,
        subscribe_id=None,
        **kwargs,
    ) -> typing.Union[typing.List[MessagesSendUserIdsResponseItem], int]:
        """Sends a message.

        :param user_id: User ID (by default — current user).
        :param random_id: Unique identifier to avoid resending the message.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
        :param peer_ids: IDs of message recipients. (See peer_id)
        :param domain: User's short address (for example, 'illarionov').
        :param chat_id: ID of conversation the message will relate to.
        :param user_ids: IDs of message recipients (if new conversation shall be started).
        :param message: (Required if 'attachments' is not set.) Text of the message.
        :param lat: Geographical latitude of a check-in, in degrees (from -90 to 90).
        :param long: Geographical longitude of a check-in, in degrees (from -180 to 180).
        :param attachment: (Required if 'message' is not set.) List of objects attached to the message, separated by commas, in the following format: "<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, 'wall' — wall post, '<owner_id>' — ID of the media attachment owner. '<media_id>' — media attachment ID. Example: "photo100172_166443618"
        :param reply_to:
        :param forward_messages: ID of forwarded messages, separated with a comma. Listed messages of the sender will be shown in the message body at the recipient's. Example: "123,431,544"
        :param forward: JSON describing the forwarded message or reply
        :param sticker_id: Sticker id.
        :param group_id: Group ID (for group messages with group access token)
        :param keyboard:
        :param template:
        :param payload:
        :param content_source: JSON describing the content source in the message
        :param dont_parse_links:
        :param disable_mentions:
        :param intent:
        :param subscribe_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.send", params)
        model = self.get_model(
            (
                (("user_ids",), MessagesSendUserIdsResponse),
                (("peer_ids",), MessagesSendPeerIdsResponse),
            ),
            default=MessagesSendDeprecatedResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload  # type: ignore
    async def get_chat(
        self,
        *,
        chat_id: int,
        name_case: typing.Optional[str] = None,
    ) -> "MessagesChat": ...

    @typing.overload
    async def get_chat(
        self,
        *,
        chat_id: int,
        fields: typing.List[UsersFields],
        name_case: typing.Optional[str] = None,
    ) -> "MessagesChatFull": ...

    @typing.overload
    async def get_chat(
        self,
        *,
        chat_ids: typing.List[int],
        name_case: typing.Optional[str] = None,
    ) -> typing.List[MessagesChat]: ...

    @typing.overload
    async def get_chat(
        self,
        *,
        chat_ids: typing.List[int],
        fields: typing.List[UsersFields],
        name_case: typing.Optional[str] = None,
    ) -> typing.List[MessagesChatFull]: ...

    async def get_chat(
        self,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        chat_ids: typing.Optional[typing.List[int]] = None,
        chat_id: typing.Optional[int] = None,
        name_case: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[
        "MessagesChat",
        "MessagesChatFull",
        typing.List[MessagesChat],
        typing.List[MessagesChatFull],
    ]:
        """Method `messages.getChat()`

        :param fields: Profile fields to return.
        :param chat_ids: Chat IDs.
        :param chat_id: Chat ID.
        :param name_case: Case for declension of user name and surname: 'nom' - nominative (default), 'gen' - genitive , 'dat' - dative, 'acc' - accusative , 'ins' - instrumental , 'abl' - prepositional
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getChat", params)
        model = self.get_model(
            (
                (("fields", "chat_id"), MessagesGetChatFieldsResponse),
                (("fields", "chat_ids"), MessagesGetChatChatIdsFieldsResponse),
                (("chat_id",), MessagesGetChatResponse),
                (("chat_ids",), MessagesGetChatChatIdsResponse),
            ),
            default=MessagesGetChatResponse,
            params=params,
        )
        return model(**response).response


__all__ = ("MessagesCategory",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import PrettyCardsPrettyCardOrError
from vkbottle_types.responses.pretty_cards import *  # noqa: F401,F403  # type: ignore


class PrettyCardsCategory(BaseCategory):
    async def create(
        self,
        link: str,
        owner_id: int,
        photo: str,
        title: str,
        button: typing.Optional[str] = None,
        price: typing.Optional[str] = None,
        price_old: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> PrettyCardsCreateResponseModel:
        """Method `prettyCards.create()`

        :param link:
        :param owner_id:
        :param photo:
        :param title:
        :param button:
        :param price:
        :param price_old:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.create", params)
        model = PrettyCardsCreateResponse
        return model(**response).response

    async def delete(
        self,
        card_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> PrettyCardsDeleteResponseModel:
        """Method `prettyCards.delete()`

        :param card_id:
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.delete", params)
        model = PrettyCardsDeleteResponse
        return model(**response).response

    async def edit(
        self,
        card_id: int,
        owner_id: int,
        button: typing.Optional[str] = None,
        link: typing.Optional[str] = None,
        photo: typing.Optional[str] = None,
        price: typing.Optional[str] = None,
        price_old: typing.Optional[str] = None,
        title: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> PrettyCardsEditResponseModel:
        """Method `prettyCards.edit()`

        :param card_id:
        :param owner_id:
        :param button:
        :param link:
        :param photo:
        :param price:
        :param price_old:
        :param title:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.edit", params)
        model = PrettyCardsEditResponse
        return model(**response).response

    async def get(
        self,
        owner_id: int,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> PrettyCardsGetResponseModel:
        """Method `prettyCards.get()`

        :param owner_id:
        :param count:
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.get", params)
        model = PrettyCardsGetResponse
        return model(**response).response

    async def get_by_id(
        self,
        card_ids: typing.List[int],
        owner_id: int,
        **kwargs: typing.Any,
    ) -> typing.List[PrettyCardsPrettyCardOrError]:
        """Method `prettyCards.getById()`

        :param card_ids:
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.getById", params)
        model = PrettyCardsGetByIdResponse
        return model(**response).response

    async def get_upload_url(
        self,
        **kwargs: typing.Any,
    ) -> str:
        """Method `prettyCards.getUploadURL()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("prettyCards.getUploadURL", params)
        model = PrettyCardsGetUploadURLResponse
        return model(**response).response


__all__ = ("PrettyCardsCategory",)



from enum import Enum
from typing import List, Optional, Union

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.codegen.objects import *  # noqa: F403  # type: ignore


class MessagesMessageActionStatus(Enum):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/226
    CHAT_PHOTO_UPDATE = "chat_photo_update"
    CHAT_PHOTO_REMOVE = "chat_photo_remove"
    CHAT_CREATE = "chat_create"
    CHAT_TITLE_UPDATE = "chat_title_update"
    CHAT_INVITE_USER = "chat_invite_user"
    CHAT_KICK_USER = "chat_kick_user"
    CHAT_PIN_MESSAGE = "chat_pin_message"
    CHAT_UNPIN_MESSAGE = "chat_unpin_message"
    CHAT_INVITE_USER_BY_LINK = "chat_invite_user_by_link"
    CHAT_INVITE_USER_BY_MESSAGE_REQUEST = "chat_invite_user_by_message_request"
    CHAT_SCREENSHOT = "chat_screenshot"
    CONVERSATION_STYLE_UPDATE = "conversation_style_update"


class MessagesMessageAttachmentType(Enum):  # type: ignore
    PHOTO = "photo"
    AUDIO = "audio"
    VIDEO = "video"
    DOC = "doc"
    LINK = "link"
    MARKET = "market"
    MARKET_ALBUM = "market_album"
    GIFT = "gift"
    STICKER = "sticker"
    WALL = "wall"
    WALL_REPLY = "wall_reply"
    ARTICLE = "article"
    POLL = "poll"
    CALL = "call"
    GRAFFITI = "graffiti"
    AUDIO_MESSAGE = "audio_message"
    STORY = "story"
    GROUP_CALL_IN_PROGRESS = (
        "group_call_in_progress"  # https://github.com/VKCOM/vk-api-schema/issues/225
    )
    MINI_APP = "mini_app"  # https://github.com/VKCOM/vk-api-schema/issues/225
    VIDEO_PLAYLIST = "video_playlist"


class VideoVideoType(Enum):  # type: ignore
    VIDEO = "video"
    MUSIC_VIDEO = "music_video"
    MOVIE = "movie"
    VIDEO_MESSAGE = "video_message"
    SHORT_VIDEO = "short_video"  # https://github.com/VKCOM/vk-api-schema/issues/212
    LIVE = "live"  # https://github.com/VKCOM/vk-api-schema/issues/230


class WallWallpostAttachmentType(Enum):  # type: ignore
    """Attachment type"""

    PHOTO = "photo"
    PHOTOS_LIST = "photos_list"
    POSTED_PHOTO = "posted_photo"
    AUDIO = "audio"
    AUDIO_PLAYLIST = "audio_playlist"
    VIDEO = "video"
    DOC = "doc"
    LINK = "link"
    GRAFFITI = "graffiti"
    NOTE = "note"
    APP = "app"
    POLL = "poll"
    PAGE = "page"
    ALBUM = "album"
    MARKET_ALBUM = "market_album"
    MARKET = "market"
    EVENT = "event"
    DONUT_LINK = "donut_link"
    ARTICLE = "article"
    TEXTLIVE = "textlive"
    TEXTPOST = "textpost"
    TEXTPOST_PUBLISH = "textpost_publish"
    SITUATIONAL_THEME = "situational_theme"
    GROUP = "group"
    STICKER = "sticker"
    PODCAST = "podcast"
    PRETTY_CARDS = "pretty_cards"  # https://github.com/VKCOM/vk-api-schema/issues/232
    MINI_APP = "mini_app"  # https://github.com/VKCOM/vk-api-schema/issues/225
    CLIP = "clip"
    VIDEO_PLAYLIST = "video_playlist"


class PhotosPhoto(PhotosPhoto):  # type: ignore
    orig_photo: Optional["PhotosPhotoSizes"] = None


class PrettyCardsList(BaseModel):
    cards: Optional[List["PrettyCardsPrettyCard"]] = None


class PollsPoll(PollsPoll):  # type: ignore[no-redef]
    anonymous: Optional[bool] = None  # type: ignore[assignment]


class WallWallpostAttachment(WallWallpostAttachment):  # type: ignore
    mini_app: Optional["AppsApp"] = None
    pretty_cards: Optional["PrettyCardsList"] = None
    poll: Optional["PollsPoll"] = None


class PollsPollExtended(PollsPoll):  # type: ignore[no-redef]
    pass


class WallCommentAttachmentType(Enum):  # type: ignore
    """Attachment type"""

    PHOTO = "photo"
    AUDIO = "audio"
    VIDEO = "video"
    DOC = "doc"
    LINK = "link"
    NOTE = "note"
    PAGE = "page"
    MARKET_MARKET_ALBUM = "market_market_album"
    MARKET = "market"
    STICKER = "sticker"
    GRAFFITI = "graffiti"  # https://github.com/VKCOM/vk-api-schema/issues/233
    AUDIO_PLAYLIST = "audio_playlist"


class BaseLinkButtonActionType(Enum):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/227
    OPEN_URL = "open_url"
    JOIN_GROUP_AND_OPEN_URL = "join_group_and_open_url"


class GroupsUserXtrRole(UsersUserFull, GroupsMemberRole):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/224
    pass


class MessagesMessageAction(MessagesMessageAction):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/226
    type: "MessagesMessageActionStatus"
    style: Optional[str] = None


class GroupCallInProgress(CallsCall):
    # https://github.com/VKCOM/vk-api-schema/issues/225
    receiver_id: Optional[int] = None  # type: ignore
    time: Optional[int] = None  # type: ignore
    join_link: Optional[str] = None
    state: Optional["CallsEndState"] = None  # type: ignore


class AppsApp(AppsApp):  # type: ignore
    id: Optional[int] = None  # type: ignore
    type: Optional[str] = None  # type: ignore


class MessagesAudioMessage(MessagesAudioMessage):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/236
    transcript_state: Optional[str] = None
    transcript: Optional[str] = None


class BaseLinkAttachment(BaseLink):
    # https://github.com/VKCOM/vk-api-schema/issues/225
    photo: Optional["LinkPhoto"] = None


class LinkPhoto(PhotosPhoto):
    # https://github.com/VKCOM/vk-api-schema/issues/225
    has_tags: Optional[bool] = None  # type: ignore
    date: Optional[int] = None  # type: ignore


class PhotosPhotoAlbumFull(PhotosPhotoAlbumFull):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/228
    created: Optional[int] = None
    updated: Optional[int] = None


class PhotosPhoto(PhotosPhoto):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/229
    has_tags: Optional[bool] = None  # type: ignore


class MessagesMessage(MessagesMessage):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/225
    attachments: Optional[List["MessagesMessageAttachment"]] = None
    reply_message: Optional["MessagesForeignMessage"] = None
    fwd_messages: Optional[List["MessagesForeignMessage"]] = None  # type: ignore


class MessagesForeignMessage(MessagesForeignMessage):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/225
    attachments: Optional[List["MessagesMessageAttachment"]] = None
    reply_message: Optional["MessagesForeignMessage"] = None
    fwd_messages: Optional[List["MessagesForeignMessage"]] = None


class MessagesPinnedMessage(MessagesPinnedMessage):  # type: ignore
    attachments: Optional[List["MessagesMessageAttachment"]] = None
    reply_message: Optional["MessagesForeignMessage"] = None
    fwd_messages: Optional[List["MessagesForeignMessage"]] = None


class VideoVideo(VideoVideo):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/212
    type: Optional["VideoVideoType"] = None


class VideoVideoFull(VideoVideo, VideoVideoFull):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/212
    type: Optional["VideoVideoType"] = None


class MessagesSendUserIdsResponseItem(BaseModel):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/208
    conversation_message_id: Optional[int] = None
    error: Optional["BaseMessageError"] = None
    message_id: Optional[int]
    peer_id: int


class MessagesMessageAttachment(MessagesMessageAttachment):  # type: ignore
    # https://github.com/VKCOM/vk-api-schema/issues/225
    audio_message: Optional["MessagesAudioMessage"] = None
    story: Optional["StoriesStory"] = None
    group_call_in_progress: Optional["GroupCallInProgress"] = None
    link: Optional["BaseLinkAttachment"] = None
    wall: Optional["WallWallpostFull"] = None
    photo: Optional["PhotosPhoto"] = None
    mini_app: Optional["AppsApp"] = None
    sticker: Optional["BaseSticker"] = None
    video: Optional["VideoVideoFull"] = None
    type: "MessagesMessageAttachmentType"
    poll: Optional["PollsPoll"] = None


class BaseLinkNoProduct(BaseLinkNoProduct):  # type: ignore
    photo: Optional["PhotosPhoto"] = None


class BaseCropPhoto(BaseCropPhoto):  # type: ignore
    photo: "PhotosPhoto" = Field()


class BugtrackerAttachment(BugtrackerAttachment):  # type: ignore
    photo: Optional["PhotosPhoto"] = None


class CallbackGroupChangePhoto(CallbackGroupChangePhoto):  # type: ignore
    photo: "PhotosPhoto" = Field()


class MarketMarketAlbum(MarketMarketAlbum):  # type: ignore
    photo: Optional["PhotosPhoto"] = None


class MarketOrderItem(MarketOrderItem):  # type: ignore
    photo: Optional["PhotosPhoto"] = None


class MessagesHistoryMessageAttachment(MessagesHistoryMessageAttachment):  # type: ignore
    photo: Optional["PhotosPhoto"] = None


class PhotosPhotoAlbum(PhotosPhotoAlbum):  # type: ignore
    thumb: Optional["PhotosPhoto"] = None


class StoriesStory(StoriesStory):  # type: ignore
    photo: Optional["PhotosPhoto"] = None


class WallCommentAttachment(WallCommentAttachment):  # type: ignore
    photo: Optional["PhotosPhoto"] = None


class WallWallpostAttachment(WallWallpostAttachment):  # type: ignore
    photo: Optional["PhotosPhoto"] = None


class NewsfeedItemPhotoPhotos(NewsfeedItemPhotoPhotos):  # type: ignore
    items: Optional[List["PhotosPhoto"]] = None


class NewsfeedItemPhotoTagPhotoTags(NewsfeedItemPhotoTagPhotoTags):  # type: ignore
    items: Optional[List["PhotosPhoto"]] = None


class UsersUserFull(UsersUserFull):  # type: ignore
    photo_max_size: Optional["PhotosPhoto"] = None


class MarketMarketItemFull(MarketMarketItemFull):  # type: ignore
    photos: Optional[List["PhotosPhoto"]] = None


class MessagesKeyboardButtonPropertyAction(MessagesKeyboardButtonPropertyAction):  # type: ignore
    label: str = Field()
    type: str = Field()
    payload: str = Field()


class StoriesClickableSticker(StoriesClickableSticker):  # type: ignore[no-redef]
    poll: Optional["PollsPoll"] = None


UsersSubscriptionsItem = Union[GroupsGroupFull, UsersUserFull]  # type: ignore[misc, assignment]


localns = locals().copy()
for item in localns.values():
    if not (isinstance(item, type) and issubclass(item, BaseModel)):
        continue

    item.model_rebuild(force=True, _types_namespace=localns)

    for parent in item.__bases__:
        if parent.__name__ == item.__name__ and issubclass(parent, BaseModel):
            parent.__pydantic_fields__.update(item.__pydantic_fields__)
            item.model_rebuild(force=True, _types_namespace=localns)



from vkbottle_types.codegen.responses.donut import *  # noqa: F403,F401
from vkbottle_types.codegen.responses.groups import (  # noqa: F403,F401
    GroupsGetMembersFieldsResponse,
    GroupsGetMembersFieldsResponseModel,
)



import typing

from vkbottle_types.codegen.responses.utils import *  # noqa: F403,F401  # type: ignore


class UtilsResolveScreenNameResponse(BaseResponse):
    response: typing.Union["UtilsDomainResolved", typing.List[typing.Any]] = Field(
        default_factory=lambda: [],
    )



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    BaseCountry,
    BaseObject,
    DatabaseCity,
    DatabaseCityById,
    DatabaseFaculty,
    DatabaseRegion,
    DatabaseSchool,
    DatabaseSchoolClass,
    DatabaseStation,
    DatabaseUniversity,
)
from vkbottle_types.responses.base_response import BaseResponse


class DatabaseGetChairsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["BaseObject"] = Field()


class DatabaseGetChairsResponse(BaseResponse):
    response: "DatabaseGetChairsResponseModel" = Field()


class DatabaseGetCitiesByIdResponse(BaseResponse):
    response: typing.List["DatabaseCityById"] = Field()


class DatabaseGetCitiesResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["DatabaseCity"] = Field()


class DatabaseGetCitiesResponse(BaseResponse):
    response: "DatabaseGetCitiesResponseModel" = Field()


class DatabaseGetCountriesByIdResponse(BaseResponse):
    response: typing.List["BaseCountry"] = Field()


class DatabaseGetCountriesResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["BaseCountry"] = Field()


class DatabaseGetCountriesResponse(BaseResponse):
    response: "DatabaseGetCountriesResponseModel" = Field()


class DatabaseGetFacultiesResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["DatabaseFaculty"] = Field()


class DatabaseGetFacultiesResponse(BaseResponse):
    response: "DatabaseGetFacultiesResponseModel" = Field()


class DatabaseGetMetroStationsByIdResponse(BaseResponse):
    response: typing.List["DatabaseStation"] = Field()


class DatabaseGetMetroStationsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["DatabaseStation"] = Field()


class DatabaseGetMetroStationsResponse(BaseResponse):
    response: "DatabaseGetMetroStationsResponseModel" = Field()


class DatabaseGetRegionsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["DatabaseRegion"] = Field()


class DatabaseGetRegionsResponse(BaseResponse):
    response: "DatabaseGetRegionsResponseModel" = Field()


class DatabaseGetSchoolClassesNewResponse(BaseResponse):
    response: typing.List["DatabaseSchoolClass"] = Field()


class DatabaseGetSchoolsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["DatabaseSchool"] = Field()


class DatabaseGetSchoolsResponse(BaseResponse):
    response: "DatabaseGetSchoolsResponseModel" = Field()


class DatabaseGetUniversitiesResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["DatabaseUniversity"] = Field()


class DatabaseGetUniversitiesResponse(BaseResponse):
    response: "DatabaseGetUniversitiesResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import StorageValue
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.storage import *  # noqa: F401,F403  # type: ignore


class StorageCategory(BaseCategory):
    async def get(
        self,
        key: typing.Optional[str] = None,
        keys: typing.Optional[typing.List[str]] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.List[StorageValue]:
        """Method `storage.get()`

        :param key:
        :param keys:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("storage.get", params)
        model = StorageGetResponse
        return model(**response).response

    async def get_keys(
        self,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.List[str]:
        """Method `storage.getKeys()`

        :param count: amount of variable names the info needs to be collected from.
        :param offset:
        :param user_id: user id, whose variables names are returned if they were requested with a server method.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("storage.getKeys", params)
        model = StorageGetKeysResponse
        return model(**response).response

    async def set(
        self,
        key: str,
        user_id: typing.Optional[int] = None,
        value: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `storage.set()`

        :param key:
        :param user_id:
        :param value:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("storage.set", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("StorageCategory",)



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import PodcastExternalData
from vkbottle_types.responses.base_response import BaseResponse


class PodcastsSearchPodcastResponseModel(BaseModel):
    podcasts: typing.List["PodcastExternalData"] = Field()
    results_total: int = Field()


class PodcastsSearchPodcastResponse(BaseResponse):
    response: "PodcastsSearchPodcastResponseModel" = Field()



import json
from typing import Any, Dict, Optional

from vkbottle_types.base_model import BaseModel, Field


class BaseResponse(BaseModel):
    response: Any
    raw_json: Optional[str] = Field(default=None)

    @property
    def raw(self) -> str:
        if not self.raw_json:
            raise AttributeError(
                "You cannot get raw_json from here. Get a full raw_json from unnested response."
            )
        return self.raw_json


class DictResponse(BaseResponse):
    response: Dict[str, Any]

    def __init__(self, **data: Any) -> None:
        super().__init__(response=data)

    @property
    def raw(self) -> Optional[str]:  # type: ignore
        if not self.response:
            return None
        return json.dumps(self.response)


BaseResponse.model_rebuild(force=True)
DictResponse.model_rebuild(force=True)


__all__ = ("BaseResponse", "DictResponse")



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import VideoLiveCategory, VideoSaveResult, VideoVideoAlbumFull
from vkbottle_types.responses.base import (
    BaseBoolResponse,
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.video import *  # noqa: F401,F403  # type: ignore


class VideoCategory(BaseCategory):
    async def add(
        self,
        owner_id: int,
        video_id: int,
        target_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.add()`

        :param owner_id: ID of the user or community that owns the video. Use a negative value to designate a community ID.
        :param video_id: Video ID.
        :param target_id: identifier of a user or community to add a video to. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.add", params)
        model = BaseOkResponse
        return model(**response).response

    async def add_album(
        self,
        group_id: typing.Optional[int] = None,
        privacy: typing.Optional[typing.List[typing.Literal["0", "1", "2", "3"]]] = None,
        title: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> VideoAddAlbumResponseModel:
        """Method `video.addAlbum()`

        :param group_id: Community ID (if the album will be created in a community).
        :param privacy: new access permissions for the album. Possible values: , *'0' - all users,, *'1' - friends only,, *'2' - friends and friends of friends,, *'3' - "only me".
        :param title: Album title.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.addAlbum", params)
        model = VideoAddAlbumResponse
        return model(**response).response

    async def add_to_album(
        self,
        owner_id: int,
        video_id: int,
        album_id: typing.Optional[int] = None,
        album_ids: typing.Optional[typing.List[int]] = None,
        target_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.addToAlbum()`

        :param owner_id:
        :param video_id:
        :param album_id:
        :param album_ids:
        :param target_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.addToAlbum", params)
        model = BaseOkResponse
        return model(**response).response

    async def create_comment(
        self,
        video_id: int,
        attachments: typing.Optional[typing.List[str]] = None,
        from_group: typing.Optional[bool] = None,
        guid: typing.Optional[str] = None,
        message: typing.Optional[str] = None,
        owner_id: typing.Optional[int] = None,
        reply_to_comment: typing.Optional[int] = None,
        sticker_id: typing.Optional[int] = None,
        track_code: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `video.createComment()`

        :param video_id: Video ID.
        :param attachments: List of objects attached to the comment, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' - Type of media attachment: 'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document, '<owner_id>' - ID of the media attachment owner. '<media_id>' - Media attachment ID. Example: "photo100172_166443618,photo66748_265827614"
        :param from_group: '1' - to post the comment from a community name (only if 'owner_id'<0)
        :param guid:
        :param message: New comment text.
        :param owner_id: ID of the user or community that owns the video.
        :param reply_to_comment:
        :param sticker_id:
        :param track_code:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.createComment", params)
        model = VideoCreateCommentResponse
        return model(**response).response

    async def delete(
        self,
        video_id: int,
        owner_id: typing.Optional[int] = None,
        target_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.delete()`

        :param video_id: Video ID.
        :param owner_id: ID of the user or community that owns the video.
        :param target_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.delete", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_album(
        self,
        album_id: int,
        group_id: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.deleteAlbum()`

        :param album_id: Album ID.
        :param group_id: Community ID (if the album is owned by a community).
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.deleteAlbum", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_comment(
        self,
        comment_id: int,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.deleteComment()`

        :param comment_id: ID of the comment to be deleted.
        :param owner_id: ID of the user or community that owns the video.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.deleteComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit(
        self,
        video_id: int,
        desc: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        no_comments: typing.Optional[bool] = None,
        ord_info: typing.Optional[str] = None,
        owner_id: typing.Optional[int] = None,
        privacy_comment: typing.Optional[typing.List[str]] = None,
        privacy_view: typing.Optional[typing.List[str]] = None,
        repeat: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> VideoEditResponseModel:
        """Method `video.edit()`

        :param video_id: Video ID.
        :param desc: New video description.
        :param name: New video title.
        :param no_comments: Disable comments for the group video.
        :param ord_info:
        :param owner_id: ID of the user or community that owns the video.
        :param privacy_comment: Privacy settings for comments in a [vk.com/dev/privacy_setting|special format].
        :param privacy_view: Privacy settings in a [vk.com/dev/privacy_setting|special format]. Privacy setting is available for videos uploaded to own profile by user.
        :param repeat: '1' - to repeat the playback of the video, '0' - to play the video once,
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.edit", params)
        model = VideoEditResponse
        return model(**response).response

    async def edit_album(
        self,
        album_id: int,
        group_id: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        privacy: typing.Optional[typing.List[typing.Literal["0", "1", "2", "3"]]] = None,
        title: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.editAlbum()`

        :param album_id: Album ID.
        :param group_id: Community ID (if the album edited is owned by a community).
        :param owner_id:
        :param privacy: new access permissions for the album. Possible values: , *'0' - all users,, *'1' - friends only,, *'2' - friends and friends of friends,, *'3' - "only me".
        :param title: New album title.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.editAlbum", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_comment(
        self,
        comment_id: int,
        attachments: typing.Optional[typing.List[str]] = None,
        message: typing.Optional[str] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.editComment()`

        :param comment_id: Comment ID.
        :param attachments: List of objects attached to the comment, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' - Type of media attachment: 'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document, '<owner_id>' - ID of the media attachment owner. '<media_id>' - Media attachment ID. Example: "photo100172_166443618,photo66748_265827614"
        :param message: New comment text.
        :param owner_id: ID of the user or community that owns the video.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.editComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def get(
        self,
        album_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[str]] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        sort_album: typing.Optional[int] = None,
        videos: typing.Optional[typing.List[str]] = None,
        **kwargs: typing.Any,
    ) -> VideoGetResponseModel:
        """Method `video.get()`

        :param album_id: ID of the album containing the video(s).
        :param count: Number of videos to return.
        :param extended: '1' - to return an extended response with additional fields
        :param fields:
        :param offset: Offset needed to return a specific subset of videos.
        :param owner_id: ID of the user or community that owns the video(s).
        :param sort_album: Sort order: '0' - newest video first, '1' - oldest video first
        :param videos: Video IDs, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", Use a negative value to designate a community ID. Example: "-4363_136089719,13245770_137352259"
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.get", params)
        model = VideoGetResponse
        return model(**response).response

    async def get_album_by_id(
        self,
        album_id: int,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> "VideoVideoAlbumFull":
        """Method `video.getAlbumById()`

        :param album_id: Album ID.
        :param owner_id: identifier of a user or community to add a video to. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.getAlbumById", params)
        model = VideoGetAlbumByIdResponse
        return model(**response).response

    @typing.overload
    async def get_albums(
        self,
        extended: typing.Literal[True],
        count: typing.Optional[int] = None,
        need_system: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> VideoGetAlbumsExtendedResponseModel: ...

    @typing.overload
    async def get_albums(
        self,
        extended: typing.Optional[typing.Literal[False]] = None,
        count: typing.Optional[int] = None,
        need_system: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> VideoGetAlbumsResponseModel: ...

    async def get_albums(
        self,
        extended: typing.Optional[bool] = None,
        count: typing.Optional[int] = None,
        need_system: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[VideoGetAlbumsExtendedResponseModel, VideoGetAlbumsResponseModel]:
        """Method `video.getAlbums()`

        :param extended: '1' - to return additional information about album privacy settings for the current user
        :param count: Number of video albums to return.
        :param need_system:
        :param offset: Offset needed to return a specific subset of video albums.
        :param owner_id: ID of the user or community that owns the video album(s).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.getAlbums", params)
        model = self.get_model(
            ((("extended",), VideoGetAlbumsExtendedResponse),),
            default=VideoGetAlbumsResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def get_albums_by_video(
        self,
        owner_id: int,
        video_id: int,
        extended: typing.Literal[True],
        target_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> VideoGetAlbumsByVideoExtendedResponseModel: ...

    @typing.overload
    async def get_albums_by_video(
        self,
        owner_id: int,
        video_id: int,
        extended: typing.Optional[typing.Literal[False]] = None,
        target_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.List[int]: ...

    async def get_albums_by_video(
        self,
        owner_id: int,
        video_id: int,
        extended: typing.Optional[bool] = None,
        target_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[typing.List[int], VideoGetAlbumsByVideoExtendedResponseModel]:
        """Method `video.getAlbumsByVideo()`

        :param owner_id:
        :param video_id:
        :param extended:
        :param target_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.getAlbumsByVideo", params)
        model = self.get_model(
            ((("extended",), VideoGetAlbumsByVideoExtendedResponse),),
            default=VideoGetAlbumsByVideoResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def get_comments(
        self,
        video_id: int,
        extended: typing.Literal[True],
        comment_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        need_likes: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        sort: typing.Optional[str] = None,
        start_comment_id: typing.Optional[int] = None,
        thread_items_count: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> VideoGetCommentsExtendedResponseModel: ...

    @typing.overload
    async def get_comments(
        self,
        video_id: int,
        extended: typing.Optional[typing.Literal[False]] = None,
        comment_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        need_likes: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        sort: typing.Optional[str] = None,
        start_comment_id: typing.Optional[int] = None,
        thread_items_count: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> VideoGetCommentsResponseModel: ...

    async def get_comments(
        self,
        video_id: int,
        extended: typing.Optional[bool] = None,
        comment_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        need_likes: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        sort: typing.Optional[str] = None,
        start_comment_id: typing.Optional[int] = None,
        thread_items_count: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[VideoGetCommentsExtendedResponseModel, VideoGetCommentsResponseModel]:
        """Method `video.getComments()`

        :param video_id: Video ID.
        :param extended:
        :param comment_id:
        :param count: Number of comments to return.
        :param fields:
        :param need_likes: '1' - to return an additional 'likes' field
        :param offset: Offset needed to return a specific subset of comments.
        :param owner_id: ID of the user or community that owns the video.
        :param sort: Sort order: 'asc' - oldest comment first, 'desc' - newest comment first
        :param start_comment_id:
        :param thread_items_count:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.getComments", params)
        model = self.get_model(
            ((("extended",), VideoGetCommentsExtendedResponse),),
            default=VideoGetCommentsResponse,
            params=params,
        )
        return model(**response).response

    async def get_long_poll_server(
        self,
        video_id: int,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> VideoGetLongPollServerResponseModel:
        """Method `video.getLongPollServer()`

        :param video_id:
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.getLongPollServer", params)
        model = VideoGetLongPollServerResponse
        return model(**response).response

    async def live_get_categories(
        self,
        **kwargs: typing.Any,
    ) -> typing.List[VideoLiveCategory]:
        """Method `video.liveGetCategories()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("video.liveGetCategories", params)
        model = VideoLiveGetCategoriesResponse
        return model(**response).response

    async def remove_from_album(
        self,
        owner_id: int,
        video_id: int,
        album_id: typing.Optional[int] = None,
        album_ids: typing.Optional[typing.List[int]] = None,
        target_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.removeFromAlbum()`

        :param owner_id:
        :param video_id:
        :param album_id:
        :param album_ids:
        :param target_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.removeFromAlbum", params)
        model = BaseOkResponse
        return model(**response).response

    async def reorder_albums(
        self,
        album_id: int,
        after: typing.Optional[int] = None,
        before: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.reorderAlbums()`

        :param album_id: Album ID.
        :param after: ID of the album after which the album in question shall be placed.
        :param before: ID of the album before which the album in question shall be placed.
        :param owner_id: ID of the user or community that owns the albums..
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.reorderAlbums", params)
        model = BaseOkResponse
        return model(**response).response

    async def reorder_videos(
        self,
        owner_id: int,
        video_id: int,
        after_owner_id: typing.Optional[int] = None,
        after_video_id: typing.Optional[int] = None,
        album_id: typing.Optional[int] = None,
        before_owner_id: typing.Optional[int] = None,
        before_video_id: typing.Optional[int] = None,
        target_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.reorderVideos()`

        :param owner_id: ID of the user or community that owns the video.
        :param video_id: ID of the video.
        :param after_owner_id: ID of the user or community that owns the video after which the photo in question shall be placed.
        :param after_video_id: ID of the video after which the photo in question shall be placed.
        :param album_id: ID of the video album.
        :param before_owner_id: ID of the user or community that owns the video before which the video in question shall be placed.
        :param before_video_id: ID of the video before which the video in question shall be placed.
        :param target_id: ID of the user or community that owns the album with videos.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.reorderVideos", params)
        model = BaseOkResponse
        return model(**response).response

    async def report(
        self,
        owner_id: int,
        video_id: int,
        comment: typing.Optional[str] = None,
        reason: typing.Optional[int] = None,
        search_query: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.report()`

        :param owner_id: ID of the user or community that owns the video.
        :param video_id: Video ID.
        :param comment: Comment describing the complaint.
        :param reason: Reason for the complaint: '0' - spam, '1' - child pornography, '2' - extremism, '3' - violence, '4' - drug propaganda, '5' - adult material, '6' - insult, abuse
        :param search_query: (If the video was found in search results.) Search query string.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.report", params)
        model = BaseOkResponse
        return model(**response).response

    async def report_comment(
        self,
        comment_id: int,
        owner_id: int,
        reason: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.reportComment()`

        :param comment_id: ID of the comment being reported.
        :param owner_id: ID of the user or community that owns the video.
        :param reason: Reason for the complaint: , 0 - spam , 1 - child pornography , 2 - extremism , 3 - violence , 4 - drug propaganda , 5 - adult material , 6 - insult, abuse
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.reportComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def restore(
        self,
        video_id: int,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.restore()`

        :param video_id: Video ID.
        :param owner_id: ID of the user or community that owns the video.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.restore", params)
        model = BaseOkResponse
        return model(**response).response

    async def restore_comment(
        self,
        comment_id: int,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `video.restoreComment()`

        :param comment_id: ID of the deleted comment.
        :param owner_id: ID of the user or community that owns the video.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.restoreComment", params)
        model = BaseBoolResponse
        return model(**response).response

    async def save(
        self,
        album_id: typing.Optional[int] = None,
        compression: typing.Optional[bool] = None,
        description: typing.Optional[str] = None,
        group_id: typing.Optional[int] = None,
        is_private: typing.Optional[bool] = None,
        link: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        no_comments: typing.Optional[bool] = None,
        ord_info: typing.Optional[str] = None,
        privacy_comment: typing.Optional[typing.List[str]] = None,
        privacy_view: typing.Optional[typing.List[str]] = None,
        repeat: typing.Optional[bool] = None,
        wallpost: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> "VideoSaveResult":
        """Method `video.save()`

        :param album_id: ID of the album to which the saved video will be added.
        :param compression:
        :param description: Description of the video.
        :param group_id: ID of the community in which the video will be saved. By default, the current user's page.
        :param is_private: '1' - to designate the video as private (send it via a private message), the video will not appear on the user's video list and will not be available by ID for other users, '0' - not to designate the video as private
        :param link: URL for embedding the video from an external website.
        :param name: Name of the video.
        :param no_comments:
        :param ord_info:
        :param privacy_comment:
        :param privacy_view:
        :param repeat: '1' - to repeat the playback of the video, '0' - to play the video once,
        :param wallpost: '1' - to post the saved video on a user's wall, '0' - not to post the saved video on a user's wall
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.save", params)
        model = VideoSaveResponse
        return model(**response).response

    @typing.overload
    async def search(
        self,
        extended: typing.Literal[True],
        adult: typing.Optional[bool] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        filters: typing.Optional[
            typing.List[typing.Literal["long", "short", "vimeo", "vk", "youtube"]]
        ] = None,
        hd: typing.Optional[int] = None,
        live: typing.Optional[bool] = None,
        longer: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        q: typing.Optional[str] = None,
        search_own: typing.Optional[bool] = None,
        shorter: typing.Optional[int] = None,
        sort: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> VideoSearchExtendedResponseModel: ...

    @typing.overload
    async def search(
        self,
        extended: typing.Optional[typing.Literal[False]] = None,
        adult: typing.Optional[bool] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        filters: typing.Optional[
            typing.List[typing.Literal["long", "short", "vimeo", "vk", "youtube"]]
        ] = None,
        hd: typing.Optional[int] = None,
        live: typing.Optional[bool] = None,
        longer: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        q: typing.Optional[str] = None,
        search_own: typing.Optional[bool] = None,
        shorter: typing.Optional[int] = None,
        sort: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> VideoSearchResponseModel: ...

    async def search(
        self,
        extended: typing.Optional[bool] = None,
        adult: typing.Optional[bool] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        filters: typing.Optional[
            typing.List[typing.Literal["long", "short", "vimeo", "vk", "youtube"]]
        ] = None,
        hd: typing.Optional[int] = None,
        live: typing.Optional[bool] = None,
        longer: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        q: typing.Optional[str] = None,
        search_own: typing.Optional[bool] = None,
        shorter: typing.Optional[int] = None,
        sort: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[VideoSearchExtendedResponseModel, VideoSearchResponseModel]:
        """Method `video.search()`

        :param extended:
        :param adult: '1' - to disable the Safe Search filter, '0' - to enable the Safe Search filter
        :param count: Number of videos to return.
        :param fields:
        :param filters: Filters to apply: 'youtube' - return YouTube videos only, 'vimeo' - return Vimeo videos only, 'vk' - return VK videos only, 'short' - return short videos only, 'long' - return long videos only
        :param hd: If not null, only searches for high-definition videos.
        :param live:
        :param longer:
        :param offset: Offset needed to return a specific subset of videos.
        :param owner_id:
        :param q: Search query string (e.g., 'The Beatles').
        :param search_own:
        :param shorter:
        :param sort: Sort order: '1' - by duration, '2' - by relevance, '0' - by date added
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.search", params)
        model = self.get_model(
            ((("extended",), VideoSearchExtendedResponse),),
            default=VideoSearchResponse,
            params=params,
        )
        return model(**response).response

    async def start_streaming(
        self,
        category_id: typing.Optional[int] = None,
        description: typing.Optional[str] = None,
        group_id: typing.Optional[int] = None,
        name: typing.Optional[str] = None,
        no_comments: typing.Optional[bool] = None,
        privacy_comment: typing.Optional[typing.List[str]] = None,
        privacy_view: typing.Optional[typing.List[str]] = None,
        publish: typing.Optional[bool] = None,
        video_id: typing.Optional[int] = None,
        wallpost: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> VideoStartStreamingResponseModel:
        """Method `video.startStreaming()`

        :param category_id:
        :param description:
        :param group_id:
        :param name:
        :param no_comments:
        :param privacy_comment:
        :param privacy_view:
        :param publish:
        :param video_id:
        :param wallpost:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.startStreaming", params)
        model = VideoStartStreamingResponse
        return model(**response).response

    async def stop_streaming(
        self,
        group_id: typing.Optional[int] = None,
        video_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> VideoStopStreamingResponseModel:
        """Method `video.stopStreaming()`

        :param group_id:
        :param video_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.stopStreaming", params)
        model = VideoStopStreamingResponse
        return model(**response).response

    async def unpin_comment(
        self,
        comment_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `video.unpinComment()`

        :param comment_id:
        :param owner_id: ID of the user or community that owns the video.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("video.unpinComment", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("VideoCategory",)



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    AdsAccount,
    AdsAd,
    AdsAdLayout,
    AdsCampaign,
    AdsCategory,
    AdsClient,
    AdsCreateAdStatus,
    AdsCreateCampaignStatus,
    AdsCreateClientsStatus,
    AdsDemoStats,
    AdsFloodStats,
    AdsLinkStatus,
    AdsLookalikeRequest,
    AdsMusician,
    AdsPromotedPostReach,
    AdsRejectReason,
    AdsStats,
    AdsTargetGroup,
    AdsTargetPixelInfo,
    AdsTargSettings,
    AdsTargStats,
    AdsTargSuggestions,
    AdsTargSuggestionsCities,
    AdsTargSuggestionsRegions,
    AdsTargSuggestionsSchools,
    AdsUpdateAdsStatus,
    AdsUpdateClientsStatus,
    AdsUpdateOfficeUsersResult,
    AdsUsers,
)
from vkbottle_types.responses.base_response import BaseResponse


class AdsAddOfficeUsersResponse(BaseResponse):
    response: typing.List[bool] = Field()


class AdsCheckLinkResponse(BaseResponse):
    response: "AdsLinkStatus" = Field()


class AdsCreateAdsResponse(BaseResponse):
    response: typing.List["AdsCreateAdStatus"] = Field()


class AdsCreateCampaignsResponse(BaseResponse):
    response: typing.List["AdsCreateCampaignStatus"] = Field()


class AdsCreateClientsResponse(BaseResponse):
    response: typing.List["AdsCreateClientsStatus"] = Field()


class AdsCreateLookalikeRequestResponseModel(BaseModel):
    request_id: typing.Optional[int] = Field(
        default=None,
    )


class AdsCreateLookalikeRequestResponse(BaseResponse):
    response: "AdsCreateLookalikeRequestResponseModel" = Field()


class AdsCreateTargetGroupResponseModel(BaseModel):
    id: typing.Optional[int] = Field(
        default=None,
    )
    pixel: typing.Optional[str] = Field(
        default=None,
    )


class AdsCreateTargetGroupResponse(BaseResponse):
    response: "AdsCreateTargetGroupResponseModel" = Field()


class AdsCreateTargetPixelResponseModel(BaseModel):
    id: typing.Optional[int] = Field(
        default=None,
    )
    pixel: typing.Optional[str] = Field(
        default=None,
    )


class AdsCreateTargetPixelResponse(BaseResponse):
    response: "AdsCreateTargetPixelResponseModel" = Field()


class AdsDeleteAdsResponse(BaseResponse):
    response: typing.List[int] = Field()


class AdsDeleteCampaignsResponse(BaseResponse):
    response: typing.List[int] = Field()


class AdsDeleteClientsResponse(BaseResponse):
    response: typing.List[int] = Field()


class AdsGetAccountsResponse(BaseResponse):
    response: typing.List["AdsAccount"] = Field()


class AdsGetAdsLayoutResponse(BaseResponse):
    response: typing.List["AdsAdLayout"] = Field()


class AdsGetAdsTargetingResponse(BaseResponse):
    response: typing.List["AdsTargSettings"] = Field()


class AdsGetAdsResponse(BaseResponse):
    response: typing.List["AdsAd"] = Field()


class AdsGetBudgetResponse(BaseResponse):
    response: str = Field()


class AdsGetCampaignsResponse(BaseResponse):
    response: typing.List["AdsCampaign"] = Field()


class AdsGetCategoriesResponseModel(BaseModel):
    v1: typing.Optional[typing.List["AdsCategory"]] = Field(
        default=None,
    )
    v2: typing.Optional[typing.List["AdsCategory"]] = Field(
        default=None,
    )


class AdsGetCategoriesResponse(BaseResponse):
    response: "AdsGetCategoriesResponseModel" = Field()


class AdsGetClientsResponse(BaseResponse):
    response: typing.List["AdsClient"] = Field()


class AdsGetDemographicsResponse(BaseResponse):
    response: typing.List["AdsDemoStats"] = Field()


class AdsGetFloodStatsResponse(BaseResponse):
    response: "AdsFloodStats" = Field()


class AdsGetLookalikeRequestsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["AdsLookalikeRequest"] = Field()


class AdsGetLookalikeRequestsResponse(BaseResponse):
    response: "AdsGetLookalikeRequestsResponseModel" = Field()


class AdsGetMusiciansResponseModel(BaseModel):
    items: typing.List["AdsMusician"] = Field()


class AdsGetMusiciansResponse(BaseResponse):
    response: "AdsGetMusiciansResponseModel" = Field()


class AdsGetOfficeUsersResponse(BaseResponse):
    response: typing.List["AdsUsers"] = Field()


class AdsGetPostsReachResponse(BaseResponse):
    response: typing.List["AdsPromotedPostReach"] = Field()


class AdsGetRejectionReasonResponse(BaseResponse):
    response: "AdsRejectReason" = Field()


class AdsGetStatisticsResponse(BaseResponse):
    response: typing.List["AdsStats"] = Field()


class AdsGetSuggestionsCitiesResponse(BaseResponse):
    response: typing.List["AdsTargSuggestionsCities"] = Field()


class AdsGetSuggestionsRegionsResponse(BaseResponse):
    response: typing.List["AdsTargSuggestionsRegions"] = Field()


class AdsGetSuggestionsResponse(BaseResponse):
    response: typing.List["AdsTargSuggestions"] = Field()


class AdsGetSuggestionsSchoolsResponse(BaseResponse):
    response: typing.List["AdsTargSuggestionsSchools"] = Field()


class AdsGetTargetGroupsResponse(BaseResponse):
    response: typing.List["AdsTargetGroup"] = Field()


class AdsGetTargetPixelsResponse(BaseResponse):
    response: typing.List["AdsTargetPixelInfo"] = Field()


class AdsGetTargetingStatsResponse(BaseResponse):
    response: "AdsTargStats" = Field()


class AdsGetUploadURLResponse(BaseResponse):
    response: str = Field()


class AdsGetVideoUploadURLResponse(BaseResponse):
    response: str = Field()


class AdsImportTargetContactsResponse(BaseResponse):
    response: int = Field()


class AdsRemoveOfficeUsersResponse(BaseResponse):
    response: typing.List[bool] = Field()


class AdsRemoveTargetContactsResponseModel(BaseModel):
    result: int = Field()


class AdsRemoveTargetContactsResponse(BaseResponse):
    response: "AdsRemoveTargetContactsResponseModel" = Field()


class AdsSaveLookalikeRequestResultResponseModel(BaseModel):
    retargeting_group_id: int = Field()
    audience_count: int = Field()


class AdsSaveLookalikeRequestResultResponse(BaseResponse):
    response: "AdsSaveLookalikeRequestResultResponseModel" = Field()


class AdsShareTargetGroupResponseModel(BaseModel):
    id: int = Field()


class AdsShareTargetGroupResponse(BaseResponse):
    response: "AdsShareTargetGroupResponseModel" = Field()


class AdsUpdateAdsResponse(BaseResponse):
    response: typing.List["AdsUpdateAdsStatus"] = Field()


class AdsUpdateCampaignsResponse(BaseResponse):
    response: typing.List["AdsCreateCampaignStatus"] = Field()


class AdsUpdateClientsResponse(BaseResponse):
    response: typing.List["AdsUpdateClientsStatus"] = Field()


class AdsUpdateOfficeUsersResponse(BaseResponse):
    response: typing.List["AdsUpdateOfficeUsersResult"] = Field()



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.responses.base_response import BaseResponse


class AuthRestoreResponseModel(BaseModel):
    success: typing.Optional[int] = Field(
        default=None,
    )
    sid: typing.Optional[str] = Field(
        default=None,
    )


class AuthRestoreResponse(BaseResponse):
    response: "AuthRestoreResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import BaseUserGroupFields, DonutDonatorSubscriptionInfo
from vkbottle_types.responses.base import (
    BaseBoolResponse,
)
from vkbottle_types.responses.donut import *  # noqa: F401,F403  # type: ignore


class DonutCategory(BaseCategory):
    async def get_friends(
        self,
        owner_id: int,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        offset: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> GroupsGetMembersFieldsResponseModel:
        """Method `donut.getFriends()`

        :param owner_id:
        :param count:
        :param fields:
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("donut.getFriends", params)
        model = GroupsGetMembersFieldsResponse
        return model(**response).response

    async def get_subscription(
        self,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> "DonutDonatorSubscriptionInfo":
        """Method `donut.getSubscription()`

        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("donut.getSubscription", params)
        model = DonutGetSubscriptionResponse
        return model(**response).response

    async def get_subscriptions(
        self,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[BaseUserGroupFields]] = None,
        offset: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> DonutGetSubscriptionsResponseModel:
        """Method `donut.getSubscriptions()`

        :param count:
        :param fields:
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("donut.getSubscriptions", params)
        model = DonutGetSubscriptionsResponse
        return model(**response).response

    async def is_don(
        self,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `donut.isDon()`

        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("donut.isDon", params)
        model = BaseBoolResponse
        return model(**response).response


__all__ = ("DonutCategory",)



from .account import *
from .ads import *
from .adsweb import *
from .app_widgets import *
from .apps import *
from .asr import *
from .auth import *
from .base import *
from .base_response import *
from .board import *
from .bugtracker import *
from .calls import *
from .database import *
from .docs import *
from .donut import *
from .downloaded_games import *
from .fave import *
from .friends import *
from .gifts import *
from .groups import *
from .lead_forms import *
from .likes import *
from .market import *
from .messages import *
from .newsfeed import *
from .notes import *
from .notifications import *
from .orders import *
from .pages import *
from .photos import *
from .podcasts import *
from .polls import *
from .pretty_cards import *
from .search import *
from .secure import *
from .stats import *
from .status import *
from .storage import *
from .store import *
from .stories import *
from .streaming import *
from .translations import *
from .users import *
from .utils import *
from .video import *
from .wall import *
from .widgets import *

localns = locals().copy()
for item in localns.values():
    if not (isinstance(item, type) and issubclass(item, BaseResponse)):
        continue

    item.model_rebuild(force=True, _types_namespace=localns)

    for parent in item.__bases__:
        if parent.__name__ == item.__name__ and issubclass(parent, BaseResponse):
            parent.__pydantic_fields__.update(item.__pydantic_fields__)
            item.model_rebuild(force=True, _types_namespace=localns)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import AsrTask, BaseUploadServer
from vkbottle_types.responses.asr import *  # noqa: F401,F403  # type: ignore
from vkbottle_types.responses.base import (
    BaseGetUploadServerResponse,
)


class AsrCategory(BaseCategory):
    async def check_status(
        self,
        task_id: str,
        **kwargs: typing.Any,
    ) -> "AsrTask":
        """Method `asr.checkStatus()`

        :param task_id: ID of ASR task in UUID format.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("asr.checkStatus", params)
        model = AsrCheckStatusResponse
        return model(**response).response

    async def get_upload_url(
        self,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `asr.getUploadUrl()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("asr.getUploadUrl", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def process(
        self,
        audio: str,
        _model: str,
        **kwargs: typing.Any,
    ) -> AsrProcessResponseModel:
        """Method `asr.process()`

        :param audio: This parameter is a JSON response returned from [vk.com/dev/upload_files_2|file uploading server].
        :param model: Which model to use for recognition. `neutral` -- general purpose (interviews, TV shows, etc.), `spontaneous` -- for NSFW audios (slang, profanity, etc.)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("asr.process", params)
        model = AsrProcessResponse
        return model(**response).response


__all__ = ("AsrCategory",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import UsersFields, UsersUserFull
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.users import *  # noqa: F401,F403  # type: ignore


class UsersCategory(BaseCategory):
    async def get(
        self,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        from_group_id: typing.Optional[int] = None,
        name_case: typing.Optional[str] = None,
        user_ids: typing.Optional[typing.List[typing.Union["int", "str"]]] = None,
        **kwargs: typing.Any,
    ) -> typing.List[UsersUserFull]:
        """Method `users.get()`

        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'contacts', 'education', 'online', 'counters', 'relation', 'last_seen', 'activity', 'can_write_private_message', 'can_see_all_posts', 'can_post', 'universities', 'can_invite_to_chats'
        :param from_group_id:
        :param name_case: Case for declension of user name and surname: 'nom' - nominative (default), 'gen' - genitive , 'dat' - dative, 'acc' - accusative , 'ins' - instrumental , 'abl' - prepositional
        :param user_ids: User IDs or screen names ('screen_name'). By default, current user ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("users.get", params)
        model = UsersGetResponse
        return model(**response).response

    @typing.overload
    async def get_followers(
        self,
        fields: typing.List[UsersFields],
        count: typing.Optional[int] = None,
        name_case: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> UsersGetFollowersFieldsResponseModel: ...

    @typing.overload
    async def get_followers(
        self,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        count: typing.Optional[int] = None,
        name_case: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> UsersGetFollowersResponseModel: ...

    async def get_followers(
        self,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        count: typing.Optional[int] = None,
        name_case: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[UsersGetFollowersFieldsResponseModel, UsersGetFollowersResponseModel]:
        """Method `users.getFollowers()`

        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online'.
        :param count: Number of followers to return.
        :param name_case: Case for declension of user name and surname: 'nom' - nominative (default), 'gen' - genitive , 'dat' - dative, 'acc' - accusative , 'ins' - instrumental , 'abl' - prepositional
        :param offset: Offset needed to return a specific subset of followers.
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("users.getFollowers", params)
        model = self.get_model(
            ((("fields",), UsersGetFollowersFieldsResponse),),
            default=UsersGetFollowersResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def get_subscriptions(
        self,
        extended: typing.Literal[True],
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        offset: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> UsersGetSubscriptionsExtendedResponseModel: ...

    @typing.overload
    async def get_subscriptions(
        self,
        extended: typing.Optional[typing.Literal[False]] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        offset: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> UsersGetSubscriptionsResponseModel: ...

    async def get_subscriptions(
        self,
        extended: typing.Optional[bool] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        offset: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[UsersGetSubscriptionsExtendedResponseModel, UsersGetSubscriptionsResponseModel]:
        """Method `users.getSubscriptions()`

        :param extended: '1' - to return a combined list of users and communities, '0' - to return separate lists of users and communities (default)
        :param count: Number of users and communities to return.
        :param fields:
        :param offset: Offset needed to return a specific subset of subscriptions.
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("users.getSubscriptions", params)
        model = self.get_model(
            ((("extended",), UsersGetSubscriptionsExtendedResponse),),
            default=UsersGetSubscriptionsResponse,
            params=params,
        )
        return model(**response).response

    async def report(
        self,
        type: str,
        user_id: int,
        comment: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `users.report()`

        :param type: Type of complaint: 'porn' - pornography, 'spam' - spamming, 'insult' - abusive behavior, 'advertisement' - disruptive advertisements
        :param user_id: ID of the user about whom a complaint is being made.
        :param comment: Comment describing the complaint.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("users.report", params)
        model = BaseOkResponse
        return model(**response).response

    async def search(
        self,
        age_from: typing.Optional[int] = None,
        age_to: typing.Optional[int] = None,
        birth_day: typing.Optional[int] = None,
        birth_month: typing.Optional[int] = None,
        birth_year: typing.Optional[int] = None,
        city: typing.Optional[int] = None,
        city_id: typing.Optional[int] = None,
        company: typing.Optional[str] = None,
        count: typing.Optional[int] = None,
        country: typing.Optional[int] = None,
        country_id: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        from_group_id: typing.Optional[int] = None,
        from_list: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        has_photo: typing.Optional[bool] = None,
        hometown: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        online: typing.Optional[bool] = None,
        position: typing.Optional[str] = None,
        q: typing.Optional[str] = None,
        religion: typing.Optional[str] = None,
        school: typing.Optional[int] = None,
        school_city: typing.Optional[int] = None,
        school_class: typing.Optional[int] = None,
        school_country: typing.Optional[int] = None,
        school_year: typing.Optional[int] = None,
        screen_ref: typing.Optional[str] = None,
        sex: typing.Optional[int] = None,
        sort: typing.Optional[int] = None,
        status: typing.Optional[int] = None,
        university: typing.Optional[int] = None,
        university_chair: typing.Optional[int] = None,
        university_country: typing.Optional[int] = None,
        university_faculty: typing.Optional[int] = None,
        university_year: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> UsersSearchResponseModel:
        """Method `users.search()`

        :param age_from: Minimum age.
        :param age_to: Maximum age.
        :param birth_day: Day of birth.
        :param birth_month: Month of birth.
        :param birth_year: Year of birth.
        :param city: City ID.
        :param city_id: City ID. Use parameter city instead
        :param company: Name of the company where users work.
        :param count: Number of users to return.
        :param country: Country ID.
        :param country_id: Country ID. Use parameter country instead
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online',
        :param from_group_id:
        :param from_list:
        :param group_id: ID of a community to search in communities.
        :param has_photo: '1' - with photo only, '0' - all users
        :param hometown: City name in a string.
        :param offset: Offset needed to return a specific subset of users.
        :param online: '1' - online only, '0' - all users
        :param position: Job position.
        :param q: Search query string (e.g., 'Vasya Babich').
        :param religion: Users' religious affiliation.
        :param school: ID of the school.
        :param school_city: ID of the city where users finished school.
        :param school_class:
        :param school_country: ID of the country where users finished school.
        :param school_year: School graduation year.
        :param screen_ref:
        :param sex: '1' - female, '2' - male, '0' - any (default)
        :param sort: Sort order: '1' - by date registered, '0' - by rating
        :param status: Relationship status: '0' - Not specified, '1' - Not married, '2' - In a relationship, '3' - Engaged, '4' - Married, '5' - It's complicated, '6' - Actively searching, '7' - In love, '8' - In a civil union
        :param university: ID of the institution of higher education.
        :param university_chair: Chair ID.
        :param university_country: ID of the country where the user graduated.
        :param university_faculty: Faculty ID.
        :param university_year: Year of graduation from an institution of higher education.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("users.search", params)
        model = UsersSearchResponse
        return model(**response).response


__all__ = ("UsersCategory",)



import pydantic
import typing_extensions as typing

if typing.TYPE_CHECKING:

    @typing.dataclass_transform(
        kw_only_default=True,
        field_specifiers=(pydantic.Field, pydantic.PrivateAttr),
    )
    class BaseModel(pydantic.BaseModel):
        @classmethod
        def from_raw(cls, data: bytes, /, *, strict: bool = False) -> typing.Self: ...

        def to_dict(self) -> typing.Dict[str, typing.Any]: ...

else:

    class BaseModel(pydantic.BaseModel):
        model_config = pydantic.ConfigDict(frozen=True)

        @classmethod
        def from_raw(cls, data, /, *, strict=False):
            return cls.model_validate_json(data, strict=strict)

        def to_dict(self):
            return cls.model_dump()


Field = pydantic.Field


__all__ = ("BaseModel", "Field")



import enum
import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    FriendsFriendExtendedStatus,
    FriendsFriendsList,
    FriendsFriendStatus,
    FriendsMutualFriend,
    FriendsOnlineUsers,
    FriendsOnlineUsersWithMobile,
    FriendsRequestsXtrMessage,
    FriendsRequestsXtrMutual,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class FriendsAddListResponseModel(BaseModel):
    list_id: int = Field()


class FriendsAddListResponse(BaseResponse):
    response: "FriendsAddListResponseModel" = Field()


class FriendsAddResponseModel(enum.IntEnum):
    SEND = 1
    APPROVED = 2
    RESEND = 4


class FriendsAddResponse(BaseResponse):
    response: "FriendsAddResponseModel" = Field()


class FriendsAreFriendsExtendedResponse(BaseResponse):
    response: typing.List["FriendsFriendExtendedStatus"] = Field()


class FriendsAreFriendsResponse(BaseResponse):
    response: typing.List["FriendsFriendStatus"] = Field()


class FriendsDeleteResponseModel(BaseModel):
    success: int = Field(default=1)
    friend_deleted: typing.Optional[int] = Field(
        default=None,
    )
    out_request_deleted: typing.Optional[int] = Field(
        default=None,
    )
    in_request_deleted: typing.Optional[int] = Field(
        default=None,
    )
    suggestion_deleted: typing.Optional[int] = Field(
        default=None,
    )


class FriendsDeleteResponse(BaseResponse):
    response: "FriendsDeleteResponseModel" = Field()


class FriendsGetAppUsersResponse(BaseResponse):
    response: typing.List[int] = Field()


class FriendsGetListsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["FriendsFriendsList"] = Field()


class FriendsGetListsResponse(BaseResponse):
    response: "FriendsGetListsResponseModel" = Field()


class FriendsGetMutualResponse(BaseResponse):
    response: typing.List[int] = Field()


class FriendsGetMutualTargetUidsResponse(BaseResponse):
    response: typing.List["FriendsMutualFriend"] = Field()


class FriendsGetMutualTotalCountResponse(BaseResponse):
    response: "FriendsMutualFriend" = Field()


class FriendsGetOnlineExtendedResponse(BaseResponse):
    response: "FriendsOnlineUsers" = Field()


class FriendsGetOnlineOnlineMobileExtendedResponse(BaseResponse):
    response: "FriendsOnlineUsersWithMobile" = Field()


class FriendsGetOnlineOnlineMobileResponseModel(BaseModel):
    online: typing.List[int] = Field()
    online_mobile: typing.List[int] = Field()


class FriendsGetOnlineOnlineMobileResponse(BaseResponse):
    response: "FriendsGetOnlineOnlineMobileResponseModel" = Field()


class FriendsGetOnlineResponse(BaseResponse):
    response: typing.List[int] = Field()


class FriendsGetRecentResponse(BaseResponse):
    response: typing.List[int] = Field()


class FriendsGetRequestsExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["FriendsRequestsXtrMessage"] = Field()
    count_unread: typing.Optional[int] = Field(
        default=None,
    )
    last_viewed: typing.Optional[int] = Field(
        default=None,
    )


class FriendsGetRequestsExtendedResponse(BaseResponse):
    response: "FriendsGetRequestsExtendedResponseModel" = Field()


class FriendsGetRequestsNeedMutualResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["FriendsRequestsXtrMutual"] = Field()
    count_unread: typing.Optional[int] = Field(
        default=None,
    )
    last_viewed: typing.Optional[int] = Field(
        default=None,
    )


class FriendsGetRequestsNeedMutualResponse(BaseResponse):
    response: "FriendsGetRequestsNeedMutualResponseModel" = Field()


class FriendsGetRequestsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List[int] = Field()
    count_unread: typing.Optional[int] = Field(
        default=None,
    )
    last_viewed: typing.Optional[int] = Field(
        default=None,
    )


class FriendsGetRequestsResponse(BaseResponse):
    response: "FriendsGetRequestsResponseModel" = Field()


class FriendsGetSuggestionsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["UsersUserFull"] = Field()


class FriendsGetSuggestionsResponse(BaseResponse):
    response: "FriendsGetSuggestionsResponseModel" = Field()


class FriendsGetFieldsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["UsersUserFull"] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )


class FriendsGetFieldsResponse(BaseResponse):
    response: "FriendsGetFieldsResponseModel" = Field()


class FriendsGetResponseModel(BaseModel):
    count: int = Field()
    items: typing.List[int] = Field()


class FriendsGetResponse(BaseResponse):
    response: "FriendsGetResponseModel" = Field()


class FriendsSearchResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["UsersUserFull"] = Field()


class FriendsSearchResponse(BaseResponse):
    response: "FriendsSearchResponseModel" = Field()



import enum
import typing

from vkbottle_types.base_model import Field
from vkbottle_types.objects import BaseUploadServer
from vkbottle_types.responses.base_response import BaseResponse


class BaseBoolResponse(BaseResponse):
    response: bool = Field()


class BaseGetUploadServerResponse(BaseResponse):
    response: "BaseUploadServer" = Field()


class BaseOkResponseModel(enum.IntEnum):
    OK = 1


class BaseOkResponse(BaseResponse):
    response: "BaseOkResponseModel" = Field(default=BaseOkResponseModel.OK)


class BaseUndefinedResponse(BaseResponse):
    response: typing.Dict[str, typing.Any] = Field()



import typing

if typing.TYPE_CHECKING:
    from vkbottle import ABCAPI  # type: ignore

    from vkbottle_types.base_model import BaseModel

Model = typing.TypeVar("Model")


class BaseCategory:
    def __init__(self, api: "ABCAPI") -> None:
        self.api = api

    @classmethod
    def get_set_params(cls, params: typing.Dict[str, typing.Any]) -> typing.Dict[str, typing.Any]:
        exclude_params = params.copy()
        exclude_params.update(params["kwargs"])
        exclude_params.pop("kwargs")
        return {
            k[1:] if k.startswith("_") else k: int(v) if isinstance(v, bool) else v
            for k, v in exclude_params.items()
            if k != "self" and v is not None
        }

    @classmethod
    def get_model(
        cls,
        dependent: typing.Tuple[
            typing.Tuple[
                typing.Tuple[typing.Union[str, typing.Sequence[str]], ...],
                typing.Type["BaseModel"],
            ],
            ...,
        ],
        default: Model,
        params: typing.Dict[str, typing.Any],
    ) -> Model:
        """Choices model depending on params."""

        for items in sorted(dependent, key=lambda x: len(x[0])):
            keys, model = items

            for key in keys:
                if (isinstance(key, str) and params.get(key) is None) or (
                    isinstance(key, (tuple, list)) and params.get(key[0]) not in key[1:]
                ):
                    break
            else:
                return model  # type: ignore

        return default

    @classmethod
    def construct_api(cls, api: "ABCAPI") -> "BaseCategory":
        return cls(api)


__all__ = ("BaseCategory",)



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import AsrTask
from vkbottle_types.responses.base_response import BaseResponse


class AsrCheckStatusResponse(BaseResponse):
    response: "AsrTask" = Field()


class AsrProcessResponseModel(BaseModel):
    task_id: str = Field()


class AsrProcessResponse(BaseResponse):
    response: "AsrProcessResponseModel" = Field()



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    BugtrackerAddCompanyGroupsMembersError,
    BugtrackerBugreport,
    BugtrackerBugreportSubscribeState,
    BugtrackerComment,
    BugtrackerCompanyMember,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class BugtrackerAddCompanyGroupsMembersResponseModel(BaseModel):
    errors: typing.List["BugtrackerAddCompanyGroupsMembersError"] = Field()


class BugtrackerAddCompanyGroupsMembersResponse(BaseResponse):
    response: "BugtrackerAddCompanyGroupsMembersResponseModel" = Field()


class BugtrackerAddCompanyMembersResponseModel(BaseModel):
    errors: typing.List[str] = Field()


class BugtrackerAddCompanyMembersResponse(BaseResponse):
    response: "BugtrackerAddCompanyMembersResponseModel" = Field()


class BugtrackerCreateCommentResponseModel(BaseModel):
    comment: "BugtrackerComment" = Field()
    comment_flood: typing.Optional[bool] = Field(
        default=None,
    )
    subscribe_state: typing.Optional["BugtrackerBugreportSubscribeState"] = Field(
        default=None,
    )


class BugtrackerCreateCommentResponse(BaseResponse):
    response: "BugtrackerCreateCommentResponseModel" = Field()


class BugtrackerGetBugreportByIdResponseModel(BaseModel):
    bugreport: typing.Optional["BugtrackerBugreport"] = Field(
        default=None,
    )
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )


class BugtrackerGetBugreportByIdResponse(BaseResponse):
    response: "BugtrackerGetBugreportByIdResponseModel" = Field()


class BugtrackerGetCompanyGroupMembersResponseModel(BaseModel):
    user_ids: typing.List[int] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )


class BugtrackerGetCompanyGroupMembersResponse(BaseResponse):
    response: "BugtrackerGetCompanyGroupMembersResponseModel" = Field()


class BugtrackerGetCompanyMembersResponseModel(BaseModel):
    company_members: typing.List["BugtrackerCompanyMember"] = Field()
    count: int = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )


class BugtrackerGetCompanyMembersResponse(BaseResponse):
    response: "BugtrackerGetCompanyMembersResponseModel" = Field()


class BugtrackerGetDownloadVersionUrlResponseModel(BaseModel):
    url: str = Field()
    app_title: typing.Optional[str] = Field(
        default=None,
    )
    bundle_name: typing.Optional[str] = Field(
        default=None,
    )
    build_id: typing.Optional[int] = Field(
        default=None,
    )
    build_name: typing.Optional[str] = Field(
        default=None,
    )
    build_title: typing.Optional[str] = Field(
        default=None,
    )


class BugtrackerGetDownloadVersionUrlResponse(BaseResponse):
    response: "BugtrackerGetDownloadVersionUrlResponseModel" = Field()
